(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    137696,       2665]*)
(*NotebookOutlinePosition[    141053,       2751]*)
(*  CellTagsIndexPosition[    140487,       2736]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["PolygonTriangulation`PolygonTessellation`", "Subsection"],

Cell[TextData[{
  "Self\[Dash]intersecting polygons are called `non\[Dash]simple' as many \
problems of computational geometry are more difficult if \
self\[Dash]intersections are allowed. However, these non\[Dash]simple \
polygons can be decomposed (tessellated)  into simple polygons, i.e. polygons \
without self\[Dash]intersections. This package provides functions for \
tessellating non\[Dash]simple polygons defined in two dimensions or embedded \
in three dimensions. The result for each non\[Dash]simple polygon is a set of \
simple polygons, which can be triangulated with the ",
  StyleBox["SimplePolygonTriangulation", "MR"],
  " package."
}], "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["PolygonTessellation",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{
                            StyleBox["{",
                              "MR"], 
                            RowBox[{
                              SubscriptBox[
                                StyleBox["x",
                                  "MR"], "1"], ",", \(y\_1\)}], "}"}], 
                          ",", \({x\_2, y\_2}\), ",", "\[Ellipsis]"}], "}"}],
                      "InlineFormula"], "]"}], 
                  RowBox[{"compute", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "tessellation", " ", "of", 
                    " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "polygon"}]},
                {
                  RowBox[{
                    StyleBox["PolygonTessellation3D",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    RowBox[{
                      StyleBox["{",
                        "InlineFormula"], 
                      RowBox[{
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{
                            StyleBox[
                              SubscriptBox[
                                StyleBox["x",
                                  "MR"], "1"],
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            StyleBox[\(y\_1\),
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            SubscriptBox[
                              StyleBox["z",
                                "InlineFormula"], "1"]}], 
                          StyleBox["}",
                            "InlineFormula"]}], 
                        StyleBox[",",
                          "InlineFormula"], 
                        RowBox[{
                          StyleBox["{",
                            "InlineFormula"], 
                          RowBox[{
                            StyleBox[\(x\_2\),
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            StyleBox[\(y\_2\),
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            SubscriptBox[
                              StyleBox["z",
                                "InlineFormula"], "2"]}], 
                          StyleBox["}",
                            "InlineFormula"]}], 
                        StyleBox[",",
                          "InlineFormula"], 
                        StyleBox["\[Ellipsis]",
                          "InlineFormula"]}], 
                      StyleBox["}",
                        "InlineFormula"]}], 
                    StyleBox["]",
                      "MR"]}], 
                  RowBox[{"compute", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "tessellation", " ", "of", 
                    " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "polygon", " ", "embedded", 
                    " ", "in", " ", "three", " ", "dimensions"}]},
                {
                  RowBox[{
                    StyleBox["TessellatePolygons",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    StyleBox["expr",
                      "TI"], 
                    StyleBox["]",
                      "MR"]}], 
                  RowBox[{
                  "tessellate", " ", "all", " ", "two\[Dash]dimensional", " ",
                     "polygons", " ", "in", " ", 
                    StyleBox["expr",
                      "TI"], " "}]},
                {
                  RowBox[{
                    StyleBox["TessellatePolygons3D",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    StyleBox["expr",
                      "TI"], 
                    StyleBox["]",
                      "MR"]}], 
                  RowBox[{
                  "tessellates", " ", "all", " ", "three\[Dash]dimensional", 
                    " ", "polygons", " ", "in", " ", 
                    StyleBox["expr",
                      "TI"]}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{
  "PolygonTessellation:PolygonTessellation", 
    "PolygonTessellation:PolygonTessellation3D", 
    "PolygonTessellation:TessellatePolygons", 
    "PolygonTessellation:TessellatePolygons3D"}],

Cell["Polygon tessellation functions. ", "Caption"],

Cell[TextData[{
  "The tessellation returned by ",
  StyleBox["PolygonTessellation", "MR"],
  " and ",
  StyleBox["PolygonTessellation3D", "MR"],
  " is a list of lists of points. Each list of points represents one of the \
simple polygons of the tessellation."
}], "Text"],

Cell["This loads the package.", "MathCaption"],

Cell[BoxData[
    \(<< PolygonTriangulation`PolygonTessellation`\)], "Input",
  CellLabel->"In[1]:= "],

Cell["Here is a list of points in the plane.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data2D = 
      Table[{Cos[\[Phi]], Sin[\[Phi]]}, {\[Phi], 0, 4\ \[Pi], 
          4  \[Pi]/5}]\)], "Input",
  CellLabel->"In[2]:= "],

Cell[BoxData[
    \({{1, 0}, {1\/4\ \((\(-1\) - \@5)\), 
        1\/2\ \@\(1\/2\ \((5 - \@5)\)\)}, {1\/4\ \((\(-1\) + \@5)\), \
\(-\(1\/2\)\)\ \@\(1\/2\ \((5 + \@5)\)\)}, {1\/4\ \((\(-1\) + \@5)\), 
        1\/2\ \@\(1\/2\ \((5 + \@5)\)\)}, {1\/4\ \((\(-1\) - \@5)\), \
\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)}, {1, 0}}\)], "Output",
  CellLabel->"Out[2]= "]
}, Open  ]],

Cell["\<\
They represent a polygon with self\[Dash]intersections.\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Line[data2D]]]\)], "Input",
  CellLabel->"In[3]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.449727 0.526463 0.309017 0.309447 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .30902 m
.02381 .49091 L
.61241 .01472 L
.61241 .60332 L
.02381 .12713 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53JbLW9`00?g=cLda<C240<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7i/30`9T0I_ooc020
P800082006IVc3<cIP2009VIod:JYb8R8_mV<`00P00g??mVc9W<c9W<oiWo09Wo<iWoIYWoVIWoc9Wo
ol`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI
<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<coool0<ol0I_l0VOl0c?lc
0?lc<olcI_lcVOlcc?lcoomV0?mVI_mVVOmVoonI0?nI<ol78@L00?l78@L00?l78@L00?l78@L00:l7
00<01`L0KPL00:h70P1`1`00[0L200031`0706l7002[1`0500L71`00L0L00:X700<01`L00PL00`07
1`1^1`00Z@L00`071`031`0300L706h7002W1`801PL00`071`1^1`00YPL00`071`061`0300L706h7
002U1`0300L700L700<01`L0KPL00:@700<01`L020L00`071`1^1`00X`L00`071`091`0300L706h7
002Q1`8030L00`071`1^1`00X0L00`071`0<1`0300L706h7002O1`0300L700d700<01`L0KPL009h7
00<01`L03PL00`071`1^1`00W0L2014700<01`L0KPL009/700<01`L04@L00`071`1^1`00VPL00`07
1`0B1`0300L706h7002I1`0300L701<700<01`L0KPL009L70P0F1`0300L706h7002F1`0300L701H7
00<01`L0KPL009D700<01`L05`L00`071`1^1`00U0L00`071`0H1`0300L706h7002B1`806`L00`07
1`1^1`00T@L00`071`0K1`0300L706h7002@1`0300L701`700<01`L0KPL008l700<01`L07@L00`07
1`1^1`00SPL00`071`0N1`0300L706h7002<1`808@L00`071`1^1`00R`L00`071`0Q1`0300L706h7
002:1`0300L7028700<01`L0KPL008T700<01`L08`L00`071`1^1`001`L307d70P0V1`0300L706h7
00081`0300L000@0M`L00`071`0V1`0300L706h700091`8010L6070700<01`L09`L00`071`1^1`00
2`L00`071`071`D0JPL00`071`0X1`0300L706h7000<1`0300L700/71@1S1`80:`L00`071`1^1`00
3@L00`071`0?1`D0G@L00`071`0[1`0300L706h7000>1`8050L505L700<01`L0;0L00`071`1^1`00
40L00`071`0F1`H0D0L00`071`0]1`0300L706h7000A1`0300L701/71@191`80<0L00`071`1^1`00
4PL00`071`0O1`D0@`L00`071`0`1`0300L706h7000C1`0300L702<71@0m1`0300L7034700<01`L0
KPL001@70P0X1`H0=PL00`071`0b1`0300L706h7000F1`0300L702/71@0`1`0300L703<700<01`L0
KPL001L700<01`L0;`L502T70P0f1`0300L706h7000H1`0300L703<71@0S1`0300L703H700<01`L0
KPL001T70P0h1`H070L00`071`0g1`0300L706h7000K1`0300L703/71@0F1`0300L703P700<01`L0
KPL001`700<01`L0?`L500l70P0k1`0300L706h7000M1`0300L704<71@091`0300L703/700<01`L0
KPL001h70P181`D00`L00`071`0l1`0300L706h7000P1`0300L704X71P0l1`0300L706h7000Q1`03
00L704T70P041`D0=`L00`071`1^1`008PL00`071`171`0300L700T71@0b1`0300L706h7000S1`80
APL00`071`0?1`D0;@L00`071`1^1`009@L00`071`121`0300L701D71P0W1`0300L706h7000V1`03
00L703l70P0N1`D08PL00`071`1^1`009`L00`071`0m1`0300L702<71@0M1`0300L706h7000X1`03
00L703/700<01`L0:@L501P700<01`L0KPL002T70P0j1`0300L702l71P0B1`0300L706h7000[1`03
00L703H700<01`L0=PL500d700<01`L0KPL002`700<01`L0<`L203h71@081`0300L706h7000]1`03
00L7034700<01`L0@`L500<700<01`L0KPL002h70P0`1`0300L704T71@1_1`00<0L00`071`0/1`03
00L704d700<01`001@1Y1`00<@L00`071`0Y1`80D0L00`071`051`D0I0L0038700<01`L09`L00`07
1`1@1`0300L700X71@1O1`00<`L202H700<01`L0D@L00`071`0?1`D0FPL003D700<01`L08PL00`07
1`1B1`0300L701@71P1D1`00=PL00`071`0O1`80E@L00`071`0J1`D0C`L003L700<01`L07@L00`07
1`1E1`0300L701l71@1:1`00>0L201`700<01`L0EPL00`071`0T1`D0A@L003X700<01`L060L00`07
1`1G1`0300L702T71P0o1`00>`L00`071`0E1`80FPL00`071`0_1`D0>PL003`700<01`L04`L00`07
1`1J1`0300L703@71@0e1`00?@L00`071`0A1`0300L705/700<01`L0>@L50307000n1`8040L00`07
1`1L1`0300L703h71@0[1`00@0L00`071`0<1`0300L705d700<01`L0@`L602D700111`0300L700T7
0P1P1`0300L704T71@0P1`00@PL00`071`071`0300L7060700<01`L0CPL501/700131`801PL00`07
1`1Q1`0300L705<71@0F1`00A@L00`071`021`0300L7068700<01`L0F0L6010700161`0400L006D7
00<01`L0GPL500/700171`0300L706D700<01`L0H`L300P700161`0400L006D700<01`L0GPL500/7
00151`0300L7008700<01`L0HPL00`071`1H1`H040L004<70P061`0300L7064700<01`L0D`L501H7
00121`0300L700L700<01`L0H0L00`071`1>1`D06`L0044700<01`L02@L2060700<01`L0B@L50207
00101`0300L700`700<01`L0G@L00`071`131`H09@L003h70P0@1`0300L705`700<01`L0?PL502/7
000m1`0300L7014700<01`L0F`L00`071`0i1`D0<0L003`700<01`L04`L00`071`1J1`0300L703@7
1@0e1`00>`L00`071`0E1`80FPL00`071`0_1`D0>PL003X700<01`L060L00`071`1G1`0300L702T7
1P0o1`00>0L201`700<01`L0EPL00`071`0T1`D0A@L003L700<01`L07@L00`071`1E1`0300L701l7
1@1:1`00=PL00`071`0O1`80E@L00`071`0J1`D0C`L003D700<01`L08PL00`071`1B1`0300L701@7
1P1D1`00<`L202H700<01`L0D@L00`071`0?1`D0FPL0038700<01`L09`L00`071`1@1`0300L700X7
1@1O1`00<@L00`071`0Y1`80D0L00`071`051`D0I0L0030700<01`L0;0L00`071`1=1`0300L000D0
J@L002h70P0`1`0300L704T71@1_1`00;@L00`071`0a1`0300L704<71@031`0300L706h7000/1`03
00L703<70P0n1`D020L00`071`1^1`00:`L00`071`0f1`0300L703H71@0=1`0300L706h7000Y1`80
>PL00`071`0_1`H04PL00`071`1^1`00:0L00`071`0k1`0300L702T71@0H1`0300L706h7000W1`03
00L703d700<01`L08`L501d700<01`L0KPL002H700<01`L0?`L201h71@0R1`0300L706h7000U1`03
00L7048700<01`L05@L602L700<01`L0KPL002<70P161`0300L700l71@0]1`0300L706h7000R1`03
00L704L700<01`L02@L5038700<01`L0KPL0024700<01`L0B@L200@71@0g1`0300L706h7000P1`03
00L704X71P0l1`0300L706h7000N1`80B0L500<700<01`L0?0L00`071`1^1`007@L00`071`131`D0
2@L00`071`0k1`0300L706h7000L1`0300L703l71@0?1`80>`L00`071`1^1`006`L00`071`0k1`D0
5PL00`071`0h1`0300L706h7000I1`80>0L601`700<01`L0=`L00`071`1^1`0060L00`071`0c1`D0
8`L00`071`0f1`0300L706h7000G1`0300L702l71@0Y1`80=PL00`071`1^1`005PL00`071`0[1`D0
<0L00`071`0c1`0300L706h7000D1`80:0L603H700<01`L0<PL00`071`1^1`004`L00`071`0S1`D0
?@L00`071`0a1`0300L706h7000B1`0300L701l71@131`0300L7030700<01`L0KPL0014700<01`L0
6`L504T70P0`1`0300L706h7000@1`0300L701H71P1@1`0300L702d700<01`L0KPL000h70P0D1`D0
E`L00`071`0/1`0300L706h7000=1`0300L700l71@1M1`0300L702/700<01`L0KPL000`700<01`L0
2`L506<70P0[1`0300L706h7000;1`0300L700L71@1Z1`0300L702P700<01`L0KPL000T70P041`H0
L0L00`071`0W1`0300L706h700081`0300L000@0M`L00`071`0V1`0300L706h700071`<0O@L202H7
00<01`L0KPL008T700<01`L08`L00`071`1^1`00RPL00`071`0R1`0300L706h7002;1`0300L70247
00<01`L0KPL008`70P0Q1`0300L706h7002>1`0300L701h700<01`L0KPL008l700<01`L07@L00`07
1`1^1`00T0L00`071`0L1`0300L706h7002A1`0300L701/700<01`L0KPL009870P0K1`0300L706h7
002D1`0300L701P700<01`L0KPL009D700<01`L05`L00`071`1^1`00UPL00`071`0F1`0300L706h7
002G1`805PL00`071`1^1`00V@L00`071`0C1`0300L706h7002J1`0300L7018700<01`L0KPL009/7
00<01`L04@L00`071`1^1`00W0L2014700<01`L0KPL009h700<01`L03PL00`071`1^1`00W`L00`07
1`0=1`0300L706h7002P1`0300L700`700<01`L0KPL00:470P0<1`0300L706h7002S1`0300L700T7
00<01`L0KPL00:@700<01`L020L00`071`1^1`00Y@L00`071`071`0300L706h7002V1`0300L700H7
00<01`L0KPL00:L70P061`0300L706h7002Y1`0300L700<700<01`L0KPL00:X700<01`L00PL00`07
1`1^1`00Z`L01@071`L00707002/1`8000<700L0K`L00:h70P1`1`00[`L00`071`1^1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.856598, -0.99862, \
0.00663477, 0.0112878}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[3]= "]
}, Open  ]],

Cell["This gives the tessellation into simple polygons.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tessell = PolygonTessellation[data2D]\)], "Input",
  CellLabel->"In[4]:= "],

Cell[BoxData[
    \({{{\(-0.8090169943749475`\), \(-0.5877852522924731`\)}, \
{\(-0.11803398874989474`\), \(-0.3632712640026805`\)}, \
{\(-0.3819660112501052`\), 
          1.1102230246251565`*^-16}}, {{\(-0.3819660112501052`\), 
          1.1102230246251565`*^-16}, {\(-0.1180339887498949`\), 
          0.3632712640026805`}, {\(-0.8090169943749475`\), 
          0.5877852522924731`}}, {{\(-0.1180339887498949`\), 
          0.3632712640026805`}, {0.30901699437494756`, 
          0.22451398828979266`}, {0.30901699437494745`, 
          0.9510565162951535`}}, {{0.30901699437494756`, 
          0.22451398828979266`}, {0.3090169943749475`, \
\(-0.22451398828979274`\)}, {1.`, 
          0.`}}, {{0.3090169943749475`, \(-0.22451398828979274`\)}, \
{\(-0.11803398874989474`\), \(-0.3632712640026805`\)}, {0.30901699437494745`, \
\(-0.9510565162951535`\)}}}\)], "Output",
  CellLabel->"Out[4]= "]
}, Open  ]],

Cell["\<\
By default only polygons with an odd winding number are generated; \
thus, the simple polygons do not cover the whole polygon.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Map[Polygon, tessell]]]\)], "Input",
  CellLabel->"In[5]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.449727 0.526463 0.309017 0.309447 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.02381 .12713 m
.38759 .1966 L
.24864 .30902 L
F
.24864 .30902 m
.38759 .42143 L
.02381 .49091 L
F
.38759 .42143 m
.61241 .37849 L
.61241 .60332 L
F
.61241 .37849 m
.61241 .23954 L
.97619 .30902 L
F
.61241 .23954 m
.38759 .1966 L
.61241 .01472 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53JbLW9`00?g=cLda<C240<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7i/30`9T0I_ooc020
P800082006IVc3<cIP2009VIod:JYb8R8_mV<`00P00g??mVc9W<c9W<oiWo09Wo<iWoIYWoVIWoc9Wo
ol`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI
<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<coool0<ol0I_l0VOl0c?lc
0?lc<olcI_lcVOlcc?lcoomV0?mVI_mVVOmVoonI0?nI<ol78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00:h700<01`L0K`L00:d70P1a1`00[0L30747002[1`@0L@L00:T71P1a1`00Z0L70747002W1`P0
L@L00:H72@1a1`00Y0L;0747002S1``0L@L00:873@1a1`00X@L>0747002O1a00L@L009h74@1a1`00
W@LB0747002L1a<0L@L009/7501a1`00V@LF0747002H1aL0L@L009L7601a1`00UPLI0747002D1a/0
L@L009<7701a1`00TPLM0747002A1ah0L@L008l7801a1`00SPLQ0747002=1b80L@L008`78`1a1`00
R`LT074700291bH0L@L008P79`1a1`002@L407X7:01a1`002PL807@7:@1a1`002`L<06d7:`1a1`00
30L@06L7;01a1`003PLC0647;@1a1`003`LH05X7;P1a1`0040LL05<7<01a1`004@LP04d7<@1a1`00
4`LS04L7<P1a1`0050LW0447<`1a1`005@L/03X7=01a1`005PL`03<7=P1a1`005`Ld02d7=`1a1`00
6@Lg02L7>01a1`006PLk0247>@1a1`006`M001T7>`1a1`0070M401<7?01a1`007PM700d7?@1a1`00
7`M;00L7?P1a1`0080N?0747000Q1dd01`Lj0747000S1dX03@Le0747000T1dP04`L`0747000U1dD0
6`LZ0747000V1d<08@LU0747000W1d409`LP0747000Y1ch0;PLJ0747000Z1c/0=@LE0747000[1cT0
>`L@0747000/1cL0@PL:0747000^1c@0B0L50747000_1c40`0L00307;`1@1`H0J`L00347;@1A1`/0
IPL003<7:P1B1a00H@L003@79`1D1aD0G0L003D79@1E1aX0E`L003H78`1F1b00D@L003L78@1G1bD0
C0L003T77@1I1bX0A`L003X76`1J1bl0@PL003/76@1K1c@0?@L003`75`1L1cX0=`L003h74`1N1cl0
<PL003l74@1O1d@0;@L004073`1P1dT0:0L004473@1Q1dh08`L004<72@1S1e@07@L004@71`1T1eT0
60L004D71@1U1eh04`L004H70`1V1f<03PL00:l7J0091`00APL306H7H`0>1`00A@L506D7GP0C1`00
A0L706@7F@0H1`00@`L906<7E00M1`00@@L=0647CP0S1`00@0L?0607B@0X1`00?`LA05l7A00]1`00
?PLC05h7?`0b1`00?0LG05`7>P0g1`00>`LI05/7=00m1`00>PLK05X7;`121`00>@LM05T7:P171`00
=`LQ05L79@1<1`00=PLS05H7801A1`00=@LU05D76P1G1`00=0LW05@75@1L1`00<`LZ0587401Q1`00
<@L]05472`1V1`00<0L_05071P1[1`00;`La0<07000^1c@0B0L50747000/1cL0@PL:0747000[1cT0
>`L@0747000Z1c/0=@LE0747000Y1ch0;PLJ0747000W1d409`LP0747000V1d<08@LU0747000U1dD0
6`LZ0747000T1dP04`L`0747000S1dX03@Le0747000Q1dd01`Lj0747000P1hl0L@L001l7B`071ch0
L@L001h7A`0=1cd0L@L001`7A00C1c`0L@L001/7@00I1c/0L@L001X7>`0Q1cT0L@L001T7=`0W1cP0
L@L001L7=00]1cL0L@L001H7<00c1cH0L@L001D7;00j1c@0L@L001@79`111c<0L@L001<78`171c80
L@L00147801=1c40L@L00107701C1c00L@L000l7601J1bh0L@L000h74`1Q1bd0L@L000`7401W1b`0
L@L000/7301]1b/0L@L000X7201d1bT0L@L000T7101j1bP0L@L008P79`1a1`00R@LV0747002;1b@0
L@L008`78`1a1`00S@LR0747002>1b40L@L008l7801a1`00T@LN0747002B1ad0L@L009<7701a1`00
U0LK0747002F1aT0L@L009L7601a1`00V0LG0747002I1aH0L@L009/7501a1`00W0LC0747002M1a80
L@L009h74@1a1`00W`L@0747002Q1`h0L@L00:873@1a1`00X`L<0747002T1`/0L@L00:H72@1a1`00
Y`L80747002X1`L0L@L00:T71P1a1`00Z`L40747002/1`<0L@L00:d70P1a1`00[PL00`071`1_1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.856598, -0.99862, \
0.00663477, 0.0112878}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[5]= "]
}, Open  ]],

Cell[TextData[{
  "This tessellates a ",
  StyleBox["Polygon", "MR"],
  " primitive within a ",
  StyleBox["Graphics", "MR"],
  " object. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[TessellatePolygons[Graphics[Polygon[data2D]]]]\)], "Input",
  CellLabel->"In[6]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.449727 0.526463 0.309017 0.309447 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.02381 .12713 m
.38759 .1966 L
.24864 .30902 L
F
.24864 .30902 m
.38759 .42143 L
.02381 .49091 L
F
.38759 .42143 m
.61241 .37849 L
.61241 .60332 L
F
.61241 .37849 m
.61241 .23954 L
.97619 .30902 L
F
.61241 .23954 m
.38759 .1966 L
.61241 .01472 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53JbLW9`00?g=cLda<C240<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7i/30`9T0I_ooc020
P800082006IVc3<cIP2009VIod:JYb8R8_mV<`00P00g??mVc9W<c9W<oiWo09Wo<iWoIYWoVIWoc9Wo
ol`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI
<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<coool0<ol0I_l0VOl0c?lc
0?lc<olcI_lcVOlcc?lcoomV0?mVI_mVVOmVoonI0?nI<ol78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00:h700<01`L0K`L00:d70P1a1`00[0L30747002[1`@0L@L00:T71P1a1`00Z0L70747002W1`P0
L@L00:H72@1a1`00Y0L;0747002S1``0L@L00:873@1a1`00X@L>0747002O1a00L@L009h74@1a1`00
W@LB0747002L1a<0L@L009/7501a1`00V@LF0747002H1aL0L@L009L7601a1`00UPLI0747002D1a/0
L@L009<7701a1`00TPLM0747002A1ah0L@L008l7801a1`00SPLQ0747002=1b80L@L008`78`1a1`00
R`LT074700291bH0L@L008P79`1a1`002@L407X7:01a1`002PL807@7:@1a1`002`L<06d7:`1a1`00
30L@06L7;01a1`003PLC0647;@1a1`003`LH05X7;P1a1`0040LL05<7<01a1`004@LP04d7<@1a1`00
4`LS04L7<P1a1`0050LW0447<`1a1`005@L/03X7=01a1`005PL`03<7=P1a1`005`Ld02d7=`1a1`00
6@Lg02L7>01a1`006PLk0247>@1a1`006`M001T7>`1a1`0070M401<7?01a1`007PM700d7?@1a1`00
7`M;00L7?P1a1`0080N?0747000Q1dd01`Lj0747000S1dX03@Le0747000T1dP04`L`0747000U1dD0
6`LZ0747000V1d<08@LU0747000W1d409`LP0747000Y1ch0;PLJ0747000Z1c/0=@LE0747000[1cT0
>`L@0747000/1cL0@PL:0747000^1c@0B0L50747000_1c40`0L00307;`1@1`H0J`L00347;@1A1`/0
IPL003<7:P1B1a00H@L003@79`1D1aD0G0L003D79@1E1aX0E`L003H78`1F1b00D@L003L78@1G1bD0
C0L003T77@1I1bX0A`L003X76`1J1bl0@PL003/76@1K1c@0?@L003`75`1L1cX0=`L003h74`1N1cl0
<PL003l74@1O1d@0;@L004073`1P1dT0:0L004473@1Q1dh08`L004<72@1S1e@07@L004@71`1T1eT0
60L004D71@1U1eh04`L004H70`1V1f<03PL00:l7J0091`00APL306H7H`0>1`00A@L506D7GP0C1`00
A0L706@7F@0H1`00@`L906<7E00M1`00@@L=0647CP0S1`00@0L?0607B@0X1`00?`LA05l7A00]1`00
?PLC05h7?`0b1`00?0LG05`7>P0g1`00>`LI05/7=00m1`00>PLK05X7;`121`00>@LM05T7:P171`00
=`LQ05L79@1<1`00=PLS05H7801A1`00=@LU05D76P1G1`00=0LW05@75@1L1`00<`LZ0587401Q1`00
<@L]05472`1V1`00<0L_05071P1[1`00;`La0<07000^1c@0B0L50747000/1cL0@PL:0747000[1cT0
>`L@0747000Z1c/0=@LE0747000Y1ch0;PLJ0747000W1d409`LP0747000V1d<08@LU0747000U1dD0
6`LZ0747000T1dP04`L`0747000S1dX03@Le0747000Q1dd01`Lj0747000P1hl0L@L001l7B`071ch0
L@L001h7A`0=1cd0L@L001`7A00C1c`0L@L001/7@00I1c/0L@L001X7>`0Q1cT0L@L001T7=`0W1cP0
L@L001L7=00]1cL0L@L001H7<00c1cH0L@L001D7;00j1c@0L@L001@79`111c<0L@L001<78`171c80
L@L00147801=1c40L@L00107701C1c00L@L000l7601J1bh0L@L000h74`1Q1bd0L@L000`7401W1b`0
L@L000/7301]1b/0L@L000X7201d1bT0L@L000T7101j1bP0L@L008P79`1a1`00R@LV0747002;1b@0
L@L008`78`1a1`00S@LR0747002>1b40L@L008l7801a1`00T@LN0747002B1ad0L@L009<7701a1`00
U0LK0747002F1aT0L@L009L7601a1`00V0LG0747002I1aH0L@L009/7501a1`00W0LC0747002M1a80
L@L009h74@1a1`00W`L@0747002Q1`h0L@L00:873@1a1`00X`L<0747002T1`/0L@L00:H72@1a1`00
Y`L80747002X1`L0L@L00:T71P1a1`00Z`L40747002/1`<0L@L00:d70P1a1`00[PL00`071`1_1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.856598, -0.99862, \
0.00663477, 0.0112878}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[6]= "]
}, Open  ]],

Cell[TextData[{
  "Flat polygons embedded in three dimensions can  be tessellated similarily \
with ",
  StyleBox["PolygonTessellation3D", "MR"],
  " and ",
  StyleBox["TessellatePolygons3D", "MR"],
  ". "
}], "Text"],

Cell[TextData[{
  "Here is a list of three-dimensional points having the same ",
  StyleBox["x", "IT"],
  ", ",
  StyleBox["y", "IT"],
  " coordinates as ",
  StyleBox["data2D", "MR"],
  "."
}], "MathCaption"],

Cell[BoxData[
    \(data3D = 
      Map[Append[#, 0.3*\((#[\([\)\(1\)\(]\)] + #[\([\)\(2\)\(]\)])\)] &, 
        data2D]; \)], "Input",
  CellLabel->"In[7]:= "],

Cell["They form a flat polygon embedded in three-dimensions.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics3D[Polygon[data3D]]]\)], "Input",
  CellLabel->"In[8]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83627 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.05274 -0.0571427 1.05274 [
[ 0 0 0 0 ]
[ 1 .83627 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
.41616 .60683 m
.03908 .25019 L
s
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
.41616 .60683 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
0 0 m
1 0 L
1 .83627 L
0 .83627 L
closepath
clip
newpath
.5 Mabswid
.84301 .47078 m .35729 .64084 L .41874 .18792 L p .547 .62 .876 r
F P
0 g
s
.74941 .73227 m .14175 .33605 L .84301 .47078 L p .547 .62 .876 r
F P
0 g
s
.41874 .18792 m .74941 .73227 L p .84301 .47078 L .547 .62 .876 r
F P
0 g
s
.25 Mabswid
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{288, 240.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000l0P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53JbLW9`00?g=cLda<C240<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7i/30`9T0I_ooc020
P800082006IVc3<cIP2009VIod:JYb8R8_mV<`00P00g??mVc9W<c9W<oiWo09Wo<iWoIYWoVIWoc9Wo
ol`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI
<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<coool0<ol0I_l0VOl0c?lc
0?lc<olcI_lcVOlcc?lcoomV0?mVI_mVVOmVoonI0?nI<l470P1M1`00_`L200031`0005`7002l1`<0
0`L205`7002i1`<01PL00`07001K1`00]`L200T700@01`L0FPL00;@70`0;1`0400L705X7002b1`80
3PL01@071`L005T7002_1`<040L00`071`021`0300L705H7002]1`804`L00`071`021`0300L705H7
002Z1`<05@L00`071`031`0300L705D7002W1`<06@L00`071`031`0300L705@7002U1`8070L00`07
1`031`0300L705@7002R1`<07PL00`071`041`0300L705<7002P1`808@L00`071`051`0300L70587
002M1`<08`L00`071`051`0300L70587002K1`809PL00`071`061`0300L70547002H1`<0:0L00`07
1`071`0300L70507002E1`<0:`L00`071`071`0300L70507002C1`80;PL00`071`081`0300L704l7
002@1`<0<0L00`071`091`0300L704h7002>1`80<`L00`071`091`0300L704h7002;1`<0=@L00`07
1`0:1`0300L704d700291`80>0L00`071`0:1`0300L704d700261`<0>PL00`071`0;1`0300L704`7
00231`<0?@L00`071`0<1`0300L704/700211`80@0L00`071`0<1`0300L704/7001n1`<0@PL00`07
1`0=1`0300L704X7001l1`80A@L00`071`0>1`0300L704T7001i1`<0A`L00`071`0>1`0300L704T7
001f1`<0B`L00`071`0>1`0300L704P7001d1`80CPL00`071`0?1`0300L704L7001a1`<0D0L00`07
1`0?1`0300L704L7001_1`80D`L00`071`0@1`0300L704H7001/1`<0E@L00`071`0A1`0300L704D7
001Z1`80F0L00`071`0A1`0300L704D7001W1`<0FPL00`071`0B1`0300L704@7001T1`<0G@L00`07
1`0C1`0300L704<7001R1`80H0L00`071`0C1`0300L704<7001O1`<0HPL00`071`0D1`0300L70487
001M1`80I@L00`071`0E1`0300L70447001J1`<0I`L00`071`0E1`0300L70447001H1`80JPL00`07
1`0F1`0300L70407001E1`<0K0L00`071`0G1`0300L703l7001B1`<0K`L00`071`0G1`0300L703l7
001@1`80LPL00`071`0H1`0300L703h7001=1`<0M0L00`071`0I1`0300L703d7001;1`80M`L00`07
1`0I1`0300L703d700181`<0N@L00`071`0J1`0300L703`700151`<0O@L00`071`0J1`0300L703/7
00131`80P0L00`071`0J1`0300L703/700101`<0PPL00`071`0K1`0300L703X7000n1`80Q@L00`07
1`0L1`0300L703T7000k1`<0Q`L00`071`0L1`0300L703T7000i1`80RPL00`071`0M1`0300L703P7
000f1`<0?`L00`071`1:1`0300L701h700<01`L0=`L003<70`121`80B`L00`071`0N1`0300L703L7
000a1`80A@L20003LPL704P700<01`L07`L00`071`0f1`00;PL304L700D0LP1bT@181`0300L70207
00<01`L0=@L002`70P191`07079h07QbN0171`0300L7020700<01`L0=@L002T70`1;1`09095bT@2A
LY5b04D700<01`L08@L00`071`0d1`009`L204h700X0LWQbN01hLWQbA0L00`071`0R1`0300L703<7
000T1`<0D0L0302ALY5b07:ALY5bTD8700<01`L08PL00`071`0c1`008@L305<700d0LWQbN780LWQb
N79h044700<01`L08`L00`071`0b1`007`L205H700l0TG:ALY40TG:ALY5bTG80?`L00`071`0S1`03
00L70387000L1`<0F0L0401bN79hLWP0N79hLWQbN78n1`0300L702@700<01`L0<@L001X70P1J1`0C
07:ALY5bTG:A095bTG:ALY5bT@0l1`0300L702D700<01`L0<0L001L70`1L1`0D07QbN79hLWQb079h
LWQbN79hLWPk1`0300L702D700<01`L0<0L001D70P1O1`0F07:ALY5bTG:ALP1bTG:ALY5bTG:ALSX7
00<01`L09@L00`071`0_1`004PL3064701L0N79hLWQbN79hLP1bN79hLWQbN79hLP0i1`0300L702H7
00<01`L0;PL000l70`1T1`0I07:ALY5bTG:ALY40TG:ALY5bTG:ALY5bT@0g1`0300L702H700<01`L0
;PL000d70P1W1`0J07QbN79hLWQbN79h07QbN79hLWQbN79hLWPf1`0300L702L700<01`L0;@L000/7
0P1Y1`0L07:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALS@700<01`L0:0L00`071`0/1`002`L206P7
01h0LWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN78c1`0300L702P700<01`L0;0L000/700<01`00
I`L0802ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:A<@L00`071`0Y1`0300L702/7000;1`04
00L706H70240LWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWP0<0L00`071`0Z1`0300L702X7
000:1`0300L7008700<01`L0H`L08`2ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5b02h7
00<01`L0:PL00`071`0Z1`002PL00`071`031`0300L7068702@0LWQbN79hLWQbN79hLWQb079hLWQb
N79hLWQbN79hLWQbN78/1`80;@L00`071`0Y1`002PL00`071`041`0300L7064702H0TG:ALY5bTG:A
LY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTBL70`021`0300L702/700<01`L0:0L000X700<01`L0
1@L00`071`1P1`0W079hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79h02<70`051`03
00L702/700<01`L0:0L000X700<01`L01PL00`071`1O1`0Y095bTG:ALY5bTG:ALY5bTG:A095bTG:A
LY5bTG:ALY5bTG:ALY5bTG807PL300T700<01`L0:`L00`071`0W1`002PL00`071`071`0300L705d7
02/0N79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQb01X70`0=1`0300L702/7
00<01`L09PL000T700<01`L02@L205d702d0LY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY405@L3014700<01`L0:PL00`071`0V1`002@L00`071`0;1`0300L705X702h0N79h
LWQbN79hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79h4PL201@700<01`L0:`L00`07
1`0U1`002@L00`071`0<1`0300L705T70300LY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG8=1`<05`L00`071`0[1`0300L702@700091`0300L700d700<01`L0F0L0<@1h
LWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN7802@L301/700<01`L0
:PL00`071`0T1`002@L00`071`0>1`0300L705L703<0LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4010L301l700<01`L0:PL00`071`0S1`002@L00`071`0?1`03
00L705H703@0N79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
0`0R1`0300L702/700<01`L08PL000T700<01`L040L00`071`1D1`0b095bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY430003TG8702<700<01`L0:PL00`071`0R1`00
20L00`071`0B1`0300L705<702l0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQb
N79hLWQbN0030006N79hLWQb90L00`071`0Z1`0300L7024700081`0300L701<700<01`L0DPL0;02A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:A0`002i5bTG:ALY5bTG:A02<7
00<01`L0:PL00`071`0P1`0020L00`071`0D1`0300L7054702T0LWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWP0N79hLWQbN79hLWQbN003000?N79hLWQbN79hLWQbN79h028700<01`L0:PL00`071`0P1`00
20L00`071`0E1`0300L7050702H0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bT@<0
01BALY5bTG:ALY5bTG:ALY5bTG:ALR4700<01`L0:PL00`071`0O1`0020L00`071`0F1`0300L704l7
02<0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN003000HN79hLWQbN79hLWQbN79hLWQb
N79hLWQb8@L00`071`0Z1`0300L701h700081`0300L701L700<01`L0CPL08@2ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5b07:ALP02000MTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4080L00`07
1`0Y1`0300L701h700081`0300L701P700<01`L0C0L07P1hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN0@0021bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN1l700<01`L0:PL00`071`0M1`00
1`L00`071`0J1`0300L704/701`0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1000995bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALQh700<01`L0:PL00`071`0L1`001`L00`071`0K1`03
00L700<0A`L06@1hLWQbN79hLWQbN79hLWQbN79hLWQbN7800`00:G9hLWP0N79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQb01h700<01`L0:@L00`071`0L1`001`L00`071`0L1`0300L700L0
@PL05P1bTG:ALY5bTG:ALY5bTG:ALY5bTG83000^LY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTAd700<01`L0:@L00`071`0K1`001`L00`071`0M1`0900L71`1bN79h00D0
?@L04`1hLWQbN79hLWQbN79hLWQbN7800`00<W9hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79h70L00`071`0Z1`0300L701X700071`0300L701h700@01`L70P001i5b
TG:ALY401P0g1`0@07:ALY5bTG:ALY5bTG:ALP<003MbTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b01/700<01`L0:@L00`071`0J1`001`L00`071`0O1`03
00L7008700d0N79hLWQbN79hLWQb00D0<PL03@1hLWQbN79hLWQbN7800`00>g9hLWQbN79hLWQbN79h
LWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb01/700<01`L0:@L00`07
1`0I1`001PL00`071`0Q1`0300L700870P003g:ALY5bTG:ALY5bTG:ALP0502`700/0TG:ALY5bTG:A
LP030010LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTAT700<01`L0:PL00`071`0H1`001PL00`071`0R1`8010L0501bN79hLWQbN79hLWQb
N79hLWQb1@0W1`08079hLWQbN7830014LWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWPI1`0300L702T700<01`L060L000H700<01`L0
90L00`071`021`8001JALY5bTG:ALY5bTG:ALY5bTG:ALY5b1@0R1`05095bTG800`00BG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG8060L00`071`0Y1`0300L701L700061`0300L702D700<01`L00`L2000ILWQbN79hLWQbN79h
LWQbN79hLWQbN79hLP0501d700<0LWP00P00CG9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb01P700<01`L0:@L00`07
1`0F1`001PL00`071`0V1`0300L700@701h0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8501P7
0`00DI5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0F1`0300L702T700<01`L05PL000H700<01`L09`L00`07
1`041`80021hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPH03`L4001DLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h5PL00`071`0Y1`0300L701D700061`0300L702P700<01`L01@L09P2ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A1@071`<00`L0E`2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP0E1`0300L702P700<01`L05@L000D700<01`L0:PL00`071`051`8002QbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h1`051`1I07QbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN7805@L00`071`0X1`0300L701@700051`0300L702/700<01`L01PL0:@1bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00<000>A00000`021`1K07:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bT@0C1`0300L702T700<01`L04`L000D700<01`L0;0L00`071`061`8002=hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0030009N79hLWQbN79h00D005UhLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN00C1`0300L702P700<01`L04`L000D700<01`L0;@L00`071`071`0P
095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY43000ATG:ALY5bTG:ALY5bTG:ALY401@00EY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b4PL00`071`0X1`0300L7018700051`0300L702h700<01`L0
1`L2000JLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP3000IN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N006001ALWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb018700<01`L0:0L00`071`0A1`001@L00`071`0_1`03
00L700P701L0LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@03000RTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALPD004ibTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4@1`0300L702P700<01`L04@L000D700<01`L0
<0L00`071`081`80015hLWQbN79hLWQbN79hLWQbN003000ZN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQb1@00BW9hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h40L00`071`0X1`0300L7010700041`03
00L7038700<01`L02@L03P2ALY5bTG:ALY5bTG:A0`00<Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1@00Ag:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00l700<01`L0:0L00`071`0?1`00
10L00`071`0c1`0300L700T70P002G9hLWQbN79hLP02000jN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPD004=bN79hLWQbN79hLWP0N79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00l700<01`L09`L00`07
1`0?1`0010L00`071`0d1`0300L700X70P00195bTG830011LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG801@00@7:ALY5bTG80LY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4=1`0300L702P7
00<01`L03PL000@700<01`L0=@L00`071`0;1`@004UbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00D003abN780LWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP=1`0300L702P7
00<01`L03@L000@700<01`L0=PL00`071`081`D004mbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00D003UbTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8030L00`07
1`0W1`0300L700d700041`0300L703L700<01`L010L300D708h0LWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
30L00`071`0W1`0300L700`700031`0300L703T700<01`L00`091`8008fALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY402PL00`071`0X1`0300L700/700031`0300L703T70`0>1`2>07QbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN0X700<01`L09`L00`071`0;1`000`L00`071`0f1`<00PL200h70P00SG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP091`0300L702L700<01`L02PL000<700<01`L0<`L300L700<01`L03@L0SP1bN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN7881`0300L702P700<01`L02@L000<700<01`L0<0L300/700<01`L03@L2002=
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:A00L700<01`L09`L00`071`091`000`L00`071`0]1`<03`L00`07
1`0>1`2>07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0L700<01`L09PL200X700031`0300L702/70P0C1`03
00L700h70P00SG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP061`0300L702870`000`L01`091`000PL00`07
1`0Y1`<05PL00`071`0?1`2>079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPD700<01`L07PL400@700<01`L0
20L0008700<01`L09PL301X700<01`L03`L2002=TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00@700<01`L0
6PL300P700<01`L020L0008700<01`L08`L301h700<01`L040L0SP1hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWP41`0300L701H70`0<1`0300L700L700021`0300L702070`0R1`0300L701070P00SG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP031`0300L70147100?1`0300L700L700021`0300L701d70`0V1`0300L70147
0P00S7QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQb0PL00`071`0>1`<04`L00`071`071`000PL00`071`0J1`<0
:PL00`071`0B1`2@095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@L030L301H700<01`L01`L0008700<01`L0
5`L302h700<01`L04PL2002>LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP700P70`0I1`0300L700L700000`L0
1`0F1`<0<PL00`071`0C1`2=07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00800`L401`700<01`L01`L00003
1`0701<70`0f1`0300L701<70P00RgQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPL0100P1`0300L700L700000`L0
1`0@1`<0>PL00`071`0D1`2:095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A0`0R1`0300L700L700000`L01`0>1`80
?PL00`071`0D1`8008IbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0@700<01`L080L00`071`061`0000<700L02`L30447
00<01`L05@L0QP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1@L00`071`0O1`0300L700H700000`L01`081`<0A@L00`07
1`0E1`8008=hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN0051`0300L701l700<01`L01PL0000300L700D70`191`0300L701D7
0P00PI5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bT@071`0300L701h700<01`L01PL0000300L700870`1=1`0300L701@708<0N000
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLP081`0300L701d700<01`L01PL0000300L00080D@L201@708<0LY5b07:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@091`03
00L701`700<01`L01PL00080EPL00`071`0@1`06079hLWQb0P00NgQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN00:1`0300L701`700<01`L0
1PL000031`0705H700<01`L03`L0P`2ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00/700<01`L06`L00`071`061`000PL205H7
00<01`L03PL02@1bN79hLWQbN002001hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79h30L00`071`0K1`0300L700D700041`0300L705@700<01`L0
3@L02`2ALY5bTG:ALY5b008007FALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY403PL00`071`0J1`0300L700D700051`0300L705@700<01`L030L0PP1b
N79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN78>1`0300L701X700<01`L01@L000H700<01`L0E0L00`071`0;1`0>095bTG:ALY5bTG:A
LY42001bLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
3`L00`071`0I1`0300L700D700071`80E@L00`071`0:1`21079hLWQbN79hLWQbN79hLP1bN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h014700<01`L060L00`07
1`051`002@L00`071`1C1`0300L700P70180LY5bTG:ALY5bTG:ALY5bTG82001^TG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8A1`0300L701P700<01`L01@L000X7
00<01`L0D`L00`071`071`2207QbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN18700<01`L05`L00`071`051`002`L00`071`1C1`03
00L700H701D0LY5bTG:ALY5bTG:ALY5bTG:ALY400P00JW:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY4D1`0300L701L700<01`L010L000`700<01`L0D`L00`071`051`21
07QbN79hLWQbN79hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQb01D700<01`L05PL00`071`041`003@L205@700<01`L010L0601bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALP8006NALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A01D7
00<01`L05PL00`071`041`003`L00`071`1B1`0300L700<70800N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN1L700<01`L05@L00`07
1`041`0040L00`071`1B1`0300L7008701/0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400P00Hg:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0H1`0300L701@700<01`L010L00147
00<01`L0DPL0Q0071`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN1T700<01`L04`L00`071`041`004PL205<702401`2ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800P00Gi5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:A01X700<01`L04`L00`071`041`0050L00`071`1A1`80021bN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN08005ebN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7806`L00`071`0B1`03
00L700@7000E1`0300L7054707l0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b01d700<01`L04PL00`071`031`005PL00`071`1@1`0T
079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb0P00FGQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79h01h700<01`L04@L00`071`031`005`L2050707l0TG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b01h700<01`L04@L00`07
1`031`006@L00`071`1=1`0W079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0080
05EbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb020700<01`L040L00`071`031`006PL00`071`1<1`1n
095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:A8@L00`071`0?1`0300L700<7000K1`0300L704X702/0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQb0080059hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb8PL00`071`0>1`03
00L700<7000L1`0300L704T702/0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:A00<0052ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALR<700<01`L03PL00`071`031`007@L204T702P0N79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0`031`8004ibN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWPT1`0300L700d700<01`L00`L001l700<01`L0APL09P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5b0P081`1>07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b9@L00`071`0=1`0300L70087000P1`03
00L704D702<0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0300/70P00BWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQb9`L00`071`0<1`0300L70087000Q1`0300L704@70200LY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALP<040L0BP2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A9`L00`071`0<1`0300L70087000R1`80A0L07@1h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<050L20017LWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780:0L00`071`0;1`03
00L70087000T1`0300L7040701/0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800`0I1`1607:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALRX700<01`L02PL00`071`021`009@L00`071`0o1`0H079hLWQbN79hLWQbN79hLWQbN79hLWQb
0`0M1`8004=hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79h02X700<01`L02PL00`071`021`009PL00`071`0n1`0E095bTG:ALY5bTG:A
LY5bTG:ALY5b00<08PL20011LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80:`L00`071`091`0300L70087000W1`80?PL04P1bN79hLWQb
N79hLWQbN79hLP<09`L0@01bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN78]1`0300L700T700<01`L00@L002T700<01`L0>`L03`2ALY5bTG:A
LY5bTG:ALP0302/70P00?I5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY40;PL00`071`081`0300L70047000Z1`0300L703X700d0LWQbN79hLWQb
N79h008000<700L0;@L0?@1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN780;PL00`071`081`0300L70047000[1`0300L703T700X0TG:ALY5bTG:A
0`031`0300L702d70P00>G:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP0`1`0300L700L700<01`L00@L002`700<01`L0=`L0201hLWQbN79h0`061`03
00L702l703T0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWP0<@L00`071`061`0300L70047000]1`80=`L01@1bTG:A00<02@L00`071`0`1`8003JALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8b1`0300L700D7
00<01`L00@L002l700<01`L0=0L00`1h000200`700<01`L0<PL0=@1hLWQbN79hLWQbN79hLWQbN79h
LWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQb03<700<01`L01@L00`071`011`00<0L00`07
1`0c1`803`L00`071`0c1`80039bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTC@700<01`L010L00`071`011`00<@L00`071`131`0300L703D70380LWQbN79hLWQb
N79hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79hLSD700<01`L010L100470@L00387
0P131`0300L703H70P00;Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG8g1`0300L700<70@011`47000d1`0300L7040700<01`L0>0L0;P1hLWQbN79hLWQbN79hLWQbN79h
LWP0N79hLWQbN79hLWQbN79hLWQbN79hLWPg1`0300L700<70@011`47000e1`0300L703l700<01`L0
>@L2000ZLY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:A>@L00`071`021`40
0@L11`00=PL00`071`0n1`0300L703/702X0LWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQb
N79hLWQbN78j1`0500L71`000PL003L70P0n1`0300L703`70P009i5bTG:ALY5bTG:ALY5bTG:ALP1b
TG:ALY5bTG:ALY5bTG:ALY5bT@0k1`0400L70087000i1`0300L703/700<01`L0?PL2000TLWQbN79h
LWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79h?0L010071`021`00>PL00`071`0i1`0300L70447
02@0LY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG8m1`0300L00087000k1`0300L703P7
00<01`L0@PL2000QN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79h03h700<01`000@L003`7
00<01`L0=`L00`071`141`0P095bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY501`800@L003d7
0P0g1`0300L704D70P007G9hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQb04070P011`00?`L00`07
1`0d1`0300L704L701d0LY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bT@101`800@L0040700<01`L0
<`L00`071`181`8001UhLWQbN79hLWQbN01hLWQbN79hLWQbN79h03d710031`00@@L00`071`0b1`03
00L704X701T0TG:ALY5bTG:ALY40TG:ALY5bTG:ALY5b03T710071`00@PL2038700<01`L0B`L2000F
LWQbN79hLWQbN01hLWQbN79hLWQbN3D7100;1`00A0L00`071`0_1`0300L704d701D0LY5bTG:ALY5b
07:ALY5bTG:ALY40<PL400l700151`0300L702h700<01`L0CPL2000BN79hLWQbN780LWQbN79hLWQb
;PL401<700161`0300L702d700<01`L0D0L04P2ALY5bTG:ALP1bTG:ALY5bTB/70`0G1`00A`L202d7
00<01`L0D@L2000>LWQbN79h07QbN79hLWPX1`@06PL004T700<01`L0:PL00`071`1C1`8000bALY5b
T@2ALY5bTG8T1`@07PL004X700<01`L0:@L00`071`1E1`0<07QbN780LWQbN79h80L40287001;1`03
00L702P700<01`L0EPL20008LY5b07:ALY4M1`@09PL004`700<01`L09`L00`071`1H1`08079hLP1b
N78I1`@0:PL004d70P0W1`0300L705T70P001I40TG:A01D7100^1`00C`L00`071`0T1`0300L705/7
00@0N01h4`L30387001@1`0300L702<700<01`L0G0L20003LPL700d7100e1`00D@L00`071`0R1`03
00L705h700<01`L02@L403T7001B1`808PL00`071`1V1`@0?@L005@700<01`L07`L00`071`1R1`@0
@@L005D700<01`L07PL00`071`1N1`@0A@L005H700<01`L07@L00`071`1K1`<0B@L005L70P0M1`03
00L705L7101<1`00F@L00`071`0J1`0300L705<7101@1`00FPL00`071`0I1`0300L704l7101D1`00
F`L00`071`0H1`0300L704/7101H1`00G0L00`071`0G1`0300L704L7101L1`00G@L201L700<01`L0
A0L30607001O1`0300L701@700<01`L0@0L406<7001P1`0300L701<700<01`L0?0L406L7001Q1`03
00L7014700<01`L0>@L406/7001R1`804@L00`071`0e1`@0K`L006@700<01`L03PL00`071`0a1`@0
L`L006D700<01`L03@L00`071`0^1`<0M`L006H700<01`L030L00`071`0Z1`@0NPL006L70P0<1`03
00L702H7101n1`00J@L00`071`091`0300L7028710221`00JPL00`071`081`0300L701h710261`00
J`L00`071`071`0300L701X7102:1`00K0L00`071`061`0300L701H7102>1`00K@L200H700<01`L0
4`L30987001_1`0300L700<700<01`L03`L409D7001`1`0300L7008700<01`L02`L409T7001a1`05
00L71`002@L409d7001b1`8000<700L010L40:47001d1`8000<700000P2U1`00M@L20:T70000\
\>"],
  ImageRangeCache->{{{0, 287}, {239.812, 0}} -> {-0.000394894, 0.054276, \
0.00331252, 0.00331252}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[8]= "]
}, Open  ]],

Cell["This gives the tessellation", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tessell3D = PolygonTessellation3D[data3D]\)], "Input",
  CellLabel->"In[9]:= "],

Cell[BoxData[
    \({{{1.0000000000000002`, \(-1.3877787807814457`*^-17\), 
          0.30000000000000004`}, {0.30901699437494723`, 0.22451398828979283`, 
          0.16005929479942202`}, {0.30901699437494734`, \
\(-0.22451398828979272`\), 
          0.025350901825546418`}}, {{0.30901699437494734`, \
\(-0.22451398828979272`\), 
          0.025350901825546418`}, {\(-0.11803398874989476`\), \
\(-0.3632712640026806`\), \(-0.14439157582577258`\)}, {0.30901699437494745`, \
\(-0.9510565162951538`\), \(-0.19261185657606184`\)}}, \
{{\(-0.11803398874989476`\), \(-0.3632712640026806`\), \
\(-0.14439157582577258`\)}, {\(-0.3819660112501051`\), \
\(-1.3877787807814457`*^-17\), \(-0.11458980337503152`\)}, \
{\(-0.8090169943749476`\), \(-0.5877852522924734`\), \
\(-0.41904067400022627`\)}}, {{\(-0.3819660112501051`\), \
\(-1.3877787807814457`*^-17\), \(-0.11458980337503152`\)}, \
{\(-0.11803398874989465`\), 0.3632712640026805`, 
          0.07357118257583575`}, {\(-0.8090169943749473`\), 
          0.5877852522924732`, \(-0.06636952262474222`\)}}, \
{{\(-0.11803398874989465`\), 0.3632712640026805`, 
          0.07357118257583575`}, {0.30901699437494723`, 0.22451398828979283`, 
          0.16005929479942202`}, {0.30901699437494745`, 0.9510565162951539`, 
          0.37802205320103044`}}}\)], "Output",
  CellLabel->"Out[9]= "]
}, Open  ]],

Cell["This is the set of simple polygons in three dimensions.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics3D[Map[Polygon, tessell3D]]]\)], "Input",
  CellLabel->"In[10]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83627 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.05274 -0.0571427 1.05274 [
[ 0 0 0 0 ]
[ 1 .83627 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
.41616 .60683 m
.03908 .25019 L
s
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
.41616 .60683 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
0 0 m
1 0 L
1 .83627 L
0 .83627 L
closepath
clip
newpath
.5 Mabswid
.37777 .48994 m .52119 .58346 L .35729 .64084 L closepath p .547 .62 .876 r
F P
0 g
s
.52119 .58346 m .63484 .54367 L .74941 .73227 L closepath p .547 .62 .876 r
F P
0 g
s
.39212 .38416 m .37777 .48994 L .14175 .33605 L closepath p .547 .62 .876 r
F P
0 g
s
.84301 .47078 m .63484 .54367 L .55722 .41588 L closepath p .547 .62 .876 r
F P
0 g
s
.55722 .41588 m .39212 .38416 L .41874 .18792 L closepath p .547 .62 .876 r
F P
0 g
s
.25 Mabswid
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{288, 240.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000l0P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53JbLW9`00?g=cLda<C240<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7i/30`9T0I_ooc020
P800082006IVc3<cIP2009VIod:JYb8R8_mV<`00P00g??mVc9W<c9W<oiWo09Wo<iWoIYWoVIWoc9Wo
ol`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI
<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<coool0<ol0I_l0VOl0c?lc
0?lc<olcI_lcVOlcc?lcoomV0?mVI_mVVOmVoonI0?nI<l470P1M1`00_`L200031`0005`7002l1`<0
0`L205`7002i1`<01PL00`07001K1`00]`L200T700@01`L0FPL00;@70`0;1`0400L705X7002b1`80
3PL01@071`L005T7002_1`<040L00`071`021`0300L705H7002]1`804`L00`071`021`0300L705H7
002Z1`<05@L00`071`031`0300L705D7002W1`<06@L00`071`031`0300L705@7002U1`8070L00`07
1`031`0300L705@7002R1`<07PL00`071`041`0300L705<7002P1`808@L00`071`051`0300L70587
002M1`<08`L00`071`051`0300L70587002K1`809PL00`071`061`0300L70547002H1`<0:0L00`07
1`071`0300L70507002E1`<0:`L00`071`071`0300L70507002C1`80;PL00`071`081`0300L704l7
002@1`<0<0L00`071`091`0300L704h7002>1`80<`L00`071`091`0300L704h7002;1`<0=@L00`07
1`0:1`0300L704d700291`80>0L00`071`0:1`0300L704d700261`<0>PL00`071`0;1`0300L704`7
00231`<0?@L00`071`0<1`0300L704/700211`80@0L00`071`0<1`0300L704/7001n1`<0@PL00`07
1`0=1`0300L704X7001l1`80A@L00`071`0>1`0300L704T7001i1`<0A`L00`071`0>1`0300L704T7
001f1`<0B`L00`071`0>1`0300L704P7001d1`80CPL00`071`0?1`0300L704L7001a1`<0D0L00`07
1`0?1`0300L704L7001_1`80D`L00`071`0@1`0300L704H7001/1`<0E@L00`071`0A1`0300L704D7
001Z1`80F0L00`071`0A1`0300L704D7001W1`<0FPL00`071`0B1`0300L704@7001T1`<0G@L00`07
1`0C1`0300L704<7001R1`80H0L00`071`0C1`0300L704<7001O1`<0HPL00`071`0D1`0300L70487
001M1`80I@L00`071`0E1`0300L70447001J1`<0I`L00`071`0E1`0300L70447001H1`80JPL00`07
1`0F1`0300L70407001E1`<0K0L00`071`0G1`0300L703l7001B1`<0K`L00`071`0G1`0300L703l7
001@1`80LPL00`071`0H1`0300L703h7001=1`<0M0L00`071`0I1`0300L703d7001;1`80M`L00`07
1`0I1`0300L703d700181`<0N@L00`071`0J1`0300L703`700151`<0O@L00`071`0J1`0300L703/7
00131`80P0L00`071`0J1`0300L703/700101`<0PPL00`071`0K1`0300L703X7000n1`80Q@L00`07
1`0L1`0300L703T7000k1`<0Q`L00`071`0L1`0300L703T7000i1`80RPL00`071`0M1`0300L703P7
000f1`<0?`L00`071`1:1`0300L701h700<01`L0=`L003<70`121`80B`L00`071`0N1`0300L703L7
000a1`80A@L204/700<01`L07`L00`071`0f1`00;PL304L700<0LP00BPL00`071`0P1`0300L703D7
000/1`80B@L0101bN01:1`0300L7020700<01`L0=@L002T70`1;1`05095bT@00B@L00`071`0Q1`03
00L703@7000W1`80CPL01P1bN79h04P700<01`L08PL00`071`0c1`0090L3050700H0TG:ALP181`03
00L7028700<01`L0<`L002470`1C1`07079hLWQb00171`0300L702<700<01`L0<PL001l70P1F1`07
095bTG:A00171`0300L702<700<01`L0<PL001`70`1H1`08079hLWQbN0161`0300L702@700<01`L0
<@L001X70P1J1`0:07:ALY5bTG:A04D700<01`L09@L00`071`0`1`005`L305`700X0N79hLWQbN780
A@L00`071`0U1`0300L70307000E1`80G`L02`1bTG:ALY5bTG8004D700<01`L09@L00`071`0_1`00
4PL3064700/0N79hLWQbN79h00151`0300L702H700<01`L0;PL000l70`1T1`0<07:ALY5bTG:ALY40
A0L00`071`0V1`0300L702h7000=1`80I`L03@1hLWQbN79hLWQbN000@`L00`071`0W1`0300L702d7
000;1`80J@L03@1bTG:ALY5bTG:ALP00@`L00`071`0X1`0300L702`7000;1`80J0L03`1bN79hLWQb
N79hLWQb00121`0300L702P700<01`L0;0L000/700<01`00I`L03`2ALY5bTG:ALY5bTG:A00121`03
00L702T700<01`L0:`L000/700@01`L0IPL0401bN79hLWQbN79hLWQbN0111`0300L702X700<01`L0
:PL000X700<01`L00PL00`071`1S1`0A095bTG:ALY5bTG:ALY5bT@00@0L00`071`0Z1`0300L702X7
000:1`0300L700<700<01`L0HPL04@1bN79hLWQbN79hLWQbN78003l70P0]1`0300L702T7000:1`03
00L700@700<01`L0H@L04P2ALY5bTG:ALY5bTG:ALY5b03/70`021`0300L702/700<01`L0:0L000X7
00<01`L01@L00`071`1P1`0B079hLWQbN79hLWQbN79hLWP0>0L300D700<01`L0:`L00`071`0X1`00
2PL00`071`061`0300L705h701@0LY5bTG:ALY5bTG:ALY5bTG:A03@70`091`0300L702/700<01`L0
9`L000X700<01`L01`L00`071`1M1`0E07QbN79hLWQbN79hLWQbN79hLWP003070`0=1`0300L702/7
00<01`L09PL000T700<01`L02@L205d701D0LY5bTG:ALY5bTG:ALY5bTG:ALP00;@L3014700<01`L0
:PL00`071`0V1`002@L00`071`0;1`0300L705X701H0N79hLWQbN79hLWQbN79hLWQbN780:PL201@7
00<01`L0:`L00`071`0U1`002@L00`071`0<1`0300L705T701H0LY5bTG:ALY5bTG:ALY5bTG:ALY40
9`L301L700<01`L0:`L00`071`0T1`002@L00`071`0=1`0300L705P701L0N79hLWQbN79hLWQbN79h
LWQbN79h000S1`<06`L00`071`0Z1`0300L702@700091`0300L700h700<01`L0E`L0601bTG:ALY5b
TG:ALY5bTG:ALY5bTG:A01l70`0O1`0300L702X700<01`L08`L000T700<01`L03`L00`071`1E1`0I
079hLWQbN79hLWQbN79hLWQbN79hLWQb000L1`<08PL00`071`0[1`0300L7028700091`0300L70107
00<01`L0E0L06P2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8060L302H700<01`L0:PL00`071`0R1`00
20L00`071`0B1`0300L705<701X0LWQbN79hLWQbN79hLWQbN79hLWQbN79h01D70`0Z1`0300L702X7
00<01`L08@L000P700<01`L04`L00`071`1B1`0K095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400147
0`0^1`0300L702X700<01`L080L000P700<01`L050L00`071`1A1`0L079hLWQbN79hLWQbN79hLWQb
N79hLWQbN79h00d70`0a1`0300L702X700<01`L080L000P700<01`L05@L00`071`1@1`0L095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5b00X70`0e1`0300L702X700<01`L07`L000P700<01`L05PL00`07
1`1?1`0M079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP001PL303T700<01`L0:PL00`071`0N1`00
20L00`071`0G1`0300L704d701h0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@041`80?@L00`07
1`0Y1`0300L701h700081`0300L701P700<01`L0C0L07P1hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN0@0?`L00`071`0Z1`0300L701d700071`0300L701X700<01`L0B`L0701bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG84048700<01`L0:PL00`071`0L1`001`L00`071`0K1`0300L700<0A`L06@1h
LWQbN79hLWQbN79hLWQbN79hLWQbN7800`00179hLP131`0300L702T700<01`L070L000L700<01`L0
70L00`071`07048701H0LY5bTG:ALY5bTG:ALY5bTG:ALY5b0`0027:ALY5bTG80@`L00`071`0Y1`03
00L701/700071`0300L701d700T01`L7079hLWP01@0m1`0C07QbN79hLWQbN79hLWQbN79hLP03000;
LWQbN79hLWQbN000@`L00`071`0Z1`0300L701X700071`0300L701h700@01`L70P001i5bTG:ALY40
1@0h1`0@07:ALY5bTG:ALY5bTG:ALP<000mbTG:ALY5bTG:ALY5bT@00@`L00`071`0Y1`0300L701X7
00071`0300L701l700<01`L00PL0301hLWQbN79hLWQbN0H0<@L03P1bN79hLWQbN79hLWQb0`004g9h
LWQbN79hLWQbN79hLWQbN000@`L00`071`0Y1`0300L701T700061`0300L7024700<01`L00PL2000?
LY5bTG:ALY5bTG:ALY5b00D0;0L02`2ALY5bTG:ALY5b00<001IbTG:ALY5bTG:ALY5bTG:ALY5bTG80
@`L00`071`0Z1`0300L701P700061`0300L702870P041`80019hLWQbN79hLWQbN79hLWQbN78502L7
00P0LWQbN79hLP<001YbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04<700<01`L0:@L00`071`0H1`00
1PL00`071`0T1`0300L700<701L0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP05028700D0TG:ALP03000M
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@00A0L00`071`0Y1`0300L701L700061`0300L702D7
00<01`L00`L2000ILWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0501d700<0LWP00P008G9hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79h00141`0300L702T700<01`L05PL000H700<01`L09PL00`07
1`041`0N07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1@0H1`<002BALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@131`0300L702T700<01`L05PL000H700<01`L09`L00`071`041`80
021hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPD040L4000VLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP141`0300L702T700<01`L05@L000H700<01`L0:0L00`071`051`0U
095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0600L70`021`0Y07:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00A0L00`071`0X1`0300L701D700051`0300L702X7
00<01`L01@L2000XLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0L01@L0:@1h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP004D700<01`L0:0L00`071`0D1`00
1@L00`071`0[1`0300L700H702T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
T@030003T@0000<00PL0:P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A04@7
00<01`L0:@L00`071`0C1`001@L00`071`0/1`0300L700H70P008gQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79h00<000UhLWQbN79hLWP01@00:7QbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN0141`0300L702P700<01`L04`L000D700<01`L0;@L00`071`071`0P095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY43000?TG:ALY5bTG:ALY5bTG8000871@008i5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8004D700<01`L0:0L00`071`0B1`001@L00`071`0^1`03
00L700L70P006W9hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0`004WQbN79hLWQbN79hLWQbN79h00L7
1P007W9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04D700<01`L0:0L00`071`0A1`001@L00`07
1`0_1`0300L700P70P005I5bTG:ALY5bTG:ALY5bTG:ALY5bT@03000ETG:ALY5bTG:ALY5bTG:ALY5b
TG8000d71@006G:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@00A@L00`071`0X1`0300L7014700051`03
00L7030700<01`L02@L04P1hLWQbN79hLWQbN79hLWQbN0<001MhLWQbN79hLWQbN79hLWQbN79hLWQb
000C1`D001EbN79hLWQbN79hLWQbN79hLWQbN000A@L00`071`0X1`0300L7010700041`0300L70387
00<01`L02@L2000<LY5bTG:ALY5bTG:A0`006Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4060L5000A
LY5bTG:ALY5bTG:ALY5bT@00A@L00`071`0X1`0300L700l700041`0300L703<700<01`L02PL02P1b
N79hLWQbN782000MN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP007@L5000<LWQbN79hLWQbN780
APL00`071`0W1`0300L700l700041`0300L703@700<01`L02PL20004TG:ALP<001mbTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY4002871P001i5bTG:ALP00A@L00`071`0X1`0300L700h700041`03
00L703D700<01`L02`L4000RLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb02P71@000gP0
1`151`0300L702P700<01`L03@L000@700<01`L0=PL00`071`081`D002=bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:A000]1`D0A0L00`071`0W1`0300L700d700041`0300L703L700<01`L0
10L300D702<0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb000`1`0307P000@0@0L00`07
1`0W1`0300L700`700031`0300L703T700<01`L00`091`80022ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:A030700L0LY5bTG:A00D0>`L00`071`0X1`0300L700/700031`0300L703T70`0>1`0O
07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h000b1`0;079hLWQbN79hLWP01@0g1`0300L702L7
00<01`L02`L000<700<01`L0=PL300870P0>1`8001abTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
<PL0402ALY5bTG:ALY5bTG:ALY46038700<01`L09`L00`071`0:1`000`L00`071`0c1`<01`L00`07
1`0=1`8001YhLWQbN79hLWQbN79hLWQbN79hLWQbN79h03<701D0N79hLWQbN79hLWQbN79hLWQbN780
1@0]1`0300L702P700<01`L02@L000<700<01`L0<0L300/700<01`L03PL06P2ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG80=0L06@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG801@0Y1`0300L702L700<01`L0
2@L000<700<01`L0;@L300l700<01`L03PL2000GLWQbN79hLWQbN79hLWQbN79hLWQbN000=0L07P1b
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPD09@L00`071`0V1`802PL000<700<01`L0:`L201<7
00<01`L03`L05`1bTG:ALY5bTG:ALY5bTG:ALY5bTG8003D70280LY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5b1@0Q1`0300L702870`000`L01`091`000PL00`071`0Y1`<05PL00`071`0?1`80
01AhLWQbN79hLWQbN79hLWQbN79h03H702H0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLPD070L00`071`0N1`@010L00`071`081`000PL00`071`0V1`<06PL00`071`0@1`0C095bTG:A
LY5bTG:ALY5bTG:A000g1`0[095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LP0501P700<01`L06PL300P700<01`L020L0008700<01`L08`L301h700<01`L040L2000@LWQbN79h
LWQbN79hLWQb03P702l0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LP0501@700<01`L05PL300`700<01`L01`L0008700<01`L080L3028700<01`L04@L0401bTG:ALY5b
TG:ALY5bT@0h1`0d07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALPH03`L00`071`0A1`@03`L00`071`071`000PL00`071`0M1`<09PL00`071`0A1`8000ehLWQb
N79hLWQbN78003T703T0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWP01@0:1`0300L700h70`0C1`0300L700L700021`0300L701X70`0Z1`0300L70187
00d0TG:ALY5bTG:ALY4003X703d0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:A00D01PL00`071`0:1`<05PL00`071`071`000PL00`071`0G1`<0
;PL00`071`0B1`8000YbN79hLWQbN780>PL0@P1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0D00PL00`071`061`<06@L00`071`071`00
00<700L05PL3038700<01`L04`L20008TG:ALY5bT@0k1`16095bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@@00`L401`700<01`L0
1`L000031`0701<70`0f1`0300L701@700P0N79hLWQb03`704<0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<00PL4020700<01`L0
1`L000031`0701070`0j1`0300L701@70P0017:ALP0m1`1007:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<00`L4028700<01`L01`L00003
1`0700h70P0n1`0300L701D700@0LWP0?PL0?@1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00P021`@010L00`071`0P1`0300L700H700000`L0
1`0;1`<0@@L00`071`0E1`<0?PL0>P2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY4300041`0000T700<01`L07`L00`071`061`0000<700L020L304D7
00<01`L05PL00`071`0m1`0f07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h0`0010L0000<1`0300L701l700<01`L01PL0000300L700D70`191`0300L701D7
0`0n1`0b095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY470107
00<01`L07PL00`071`061`0000<01`L00PL304d700<01`L050L0101hLP0m1`0_079hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP01P0E1`0300L701d700<01`L01PL00003
00L00080D@L201@700@0LY5b0P0l1`0/07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG8501T700<01`L070L00`071`061`000P1F1`0300L7010700P0LWQbN79h03`702P0LWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb1@0L1`0300L701`700<01`L01PL00003
1`0705H700<01`L03`L0202ALY5bTG:A0P0j1`0U095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP05020700<01`L06`L00`071`061`000PL205H700<01`L03PL02`1bN79hLWQbN78003X7
0240N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780100U1`0300L701/700<01`L01@L000@7
00<01`L0E0L00`071`0=1`0;095bTG:ALY5bTG800P0h1`0N07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5b100Y1`0300L701X700<01`L01@L000D700<01`L0E0L00`071`0<1`0>079hLWQbN79hLWQb
N00h1`0K079hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<0;0L00`071`0J1`0300L700D700061`03
00L705@700<01`L02`L03P2ALY5bTG:ALY5bTG:A0P0g1`0G07:ALY5bTG:ALY5bTG:ALY5bTG:ALY40
0`0`1`0300L701T700<01`L01@L000L70P1E1`0300L700X70140LWQbN79hLWQbN79hLWQb000f1`0D
07QbN79hLWQbN79hLWQbN79hLWP303@700<01`L060L00`071`051`002@L00`071`1C1`0300L700P7
0180LY5bTG:ALY5bTG:ALY5bTG8203D70100TG:ALY5bTG:ALY5bTG:A0`0g1`0300L701P700<01`L0
1@L000X700<01`L0D`L00`071`071`0E07QbN79hLWQbN79hLWQbN79hLWP003D700`0N79hLWQbN79h
LWP303/700<01`L05`L00`071`051`002`L00`071`1C1`0300L700H701D0LY5bTG:ALY5bTG:ALY5b
TG:ALY400P0c1`0:07:ALY5bTG:ALP80?`L00`071`0G1`0300L700@7000<1`0300L705<700<01`L0
1@L05`1hLWQbN79hLWQbN79hLWQbN79hLWQb0080<PL01P1bN79hLP<0@PL00`071`0F1`0300L700@7
000=1`80E0L00`071`041`0J07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0`1`8000>ALP000P151`03
00L701H700<01`L010L000l700<01`L0DPL00`071`031`0J07QbN79hLWQbN79hLWQbN79hLWQbN79h
LWP202/70`0010L000191`0300L701D700<01`L010L0010700<01`L0DPL00`071`021`0M07:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP009`L300071`0007:A001:1`0300L701@700<01`L010L00147
00<01`L0DPL08@071`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0202870`002PL0001bN79h
LP1;1`0300L701<700<01`L010L001870P1C1`0S00L0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bT@007@L4000>1`0007:ALY5bTG:ALP1:1`0300L701<700<01`L010L001@700<01`L0D@L2000P
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP201P70`021`<000ebN79hLWQbN79hLWP004/7
00<01`L04PL00`071`041`005@L00`071`1A1`0T095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG8050L300870`004G:ALY5bTG:ALY5bTG:ALY4004/700<01`L04PL00`071`031`005PL00`07
1`1@1`0T079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb0P0>1`@00PL3000ELWQbN79h
LWQbN79hLWQbN79hLWP004/700<01`L04@L00`071`031`005`L2050702L0TG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@002PL300<70`0067:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b04/7
00<01`L04@L00`071`031`006@L00`071`1=1`0W079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79h00801@L300<70`00779hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1;1`0300L70107
00<01`L00`L001X700<01`L0C0L0:@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5b00D00`L3000OLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A001<1`0300L700l700<01`L0
0`L001/700<01`L0BPL0:`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780
0P021`<002=bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h001<1`0300L700h700<01`L0
0`L001`700<01`L0B@L0;01bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
0`009g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A001;1`0300L700h700<01`L0
0`L001d70P191`0Y07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800`021`80
02IbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04`700<01`L03@L00`071`031`00
7`L00`071`161`0V07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8300L702L0LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00C0L00`071`0=1`0300L70087000P1`03
00L704D702<0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0300/70P009GQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP00C0L00`071`0<1`0300L70087000Q1`0300L704@7
0200LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<040L09@2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bT@00C0L00`071`0<1`0300L70087000R1`80A0L07@1hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQb00<050L2000SLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN000
C0L00`071`0;1`0300L70087000T1`0300L7040701/0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
0`0I1`0S07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00C@L00`071`0:1`0300L70087
000U1`0300L703l701P0LWQbN79hLWQbN79hLWQbN79hLWQbN78301d70P008GQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQb001<1`0300L700X700<01`L00PL002H700<01`L0?PL05P2ALY5bTG:A
LY5bTG:ALY5bTG:ALY4202870P0087:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80C0L00`07
1`091`0300L70087000W1`80?PL04`1bN79hLWQbN79hLWQbN79hLWP00`0V1`0P079hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN01=1`0300L700T700<01`L00@L002T700<01`L0>`L0402ALY5bTG:A
LY5bTG:ALY4302X70P007Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A04d700<01`L020L00`07
1`011`00:PL00`071`0j1`0=079hLWQbN79hLWQbN00402h701h0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLP1=1`0300L700P700<01`L00@L002/700<01`L0>@L02P2ALY5bTG:ALY4300<700<01`L0
;@L2000LLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b04d700<01`L01`L00`071`011`00;0L00`07
1`0g1`0807QbN79hLWP300H700<01`L0;`L07@1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78004d7
00<01`L01PL00`071`011`00;@L203L700D0LY5bT@0300T700<01`L0<0L2000JTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bT@1>1`0300L700D700<01`L00@L002l700<01`L0=0L00`1h000200`700<01`L0
<PL06`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79h001=1`0300L700D700<01`L00@L0030700<01`L0
<`L200l700<01`L0<`L2000HLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80CPL00`071`041`0300L70047
000a1`0300L704<700<01`L0=@L06@1bN79hLWQbN79hLWQbN79hLWQbN79hLP00CPL00`071`041`40
0@L11`00<PL204<700<01`L0=PL2000GTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00CPL00`071`031`40
0@L11`00=0L00`071`101`0300L703P701L0N79hLWQbN79hLWQbN79hLWQbN79h001>1`0300L700<7
0@011`47000e1`0300L703l700<01`L0>@L2000ELY5bTG:ALY5bTG:ALY5bTG:ALY4004h700<01`L0
0PL100470@L003H700<01`L0?PL00`071`0k1`0F079hLWQbN79hLWQbN79hLWQbN79h04h700D01`L7
00021`00=`L203h700<01`L0?0L2000CTG:ALY5bTG:ALY5bTG:ALY5b001?1`0400L70087000i1`03
00L703/700<01`L0?PL2000BLWQbN79hLWQbN79hLWQbN780CPL010071`021`00>PL00`071`0i1`03
00L704470180LY5bTG:ALY5bTG:ALY5bT@1?1`0300L00087000k1`0300L703P700<01`L0@PL2000@
N79hLWQbN79hLWQbN79h04l700<01`000@L003`700<01`L0=`L00`071`141`0A095bTG:ALY5bTG:A
LY5bT@00C`L20047000m1`80=`L00`071`151`8000ibN79hLWQbN79hLWQb04l70P011`00?`L00`07
1`0d1`0300L704L700l0LY5bTG:ALY5bTG:ALP00CPL2004700101`0300L703<700<01`L0B0L2000<
N79hLWQbN79hLWP0BPL400<700111`0300L7038700<01`L0BPL03@2ALY5bTG:ALY5bT@00A@L400L7
00121`80<PL00`071`1;1`8000]bN79hLWQbN79h00101`@02`L004@700<01`L0;`L00`071`1=1`0;
07:ALY5bTG:ALP00?0L400l700151`0300L702h700<01`L0CPL20009N79hLWQbN78003L7100C1`00
APL00`071`0]1`0300L7050700T0TG:ALY5bT@00=0L301L700171`80;@L00`071`1A1`8000MbN79h
LWP002l7100J1`00B@L00`071`0Z1`0300L705<70P001Y5bTG:A02X7100N1`00BPL00`071`0Y1`03
00L705D700H0N79hLP0V1`@08PL004/700<01`L0:0L00`071`1F1`8000AbTG808@L402H7001<1`03
00L702L700<01`L0F0L01@1bN78001`7100Z1`00C@L202L700<01`L0F@L20003T@0701L7100^1`00
C`L00`071`0T1`0300L705/700<0N00050L30387001@1`0300L702<700<01`L0G0L20107100e1`00
D@L00`071`0R1`0300L705h700<01`L02@L403T7001B1`808PL00`071`1V1`@0?@L005@700<01`L0
7`L00`071`1R1`@0@@L005D700<01`L07PL00`071`1N1`@0A@L005H700<01`L07@L00`071`1K1`<0
B@L005L70P0M1`0300L705L7101<1`00F@L00`071`0J1`0300L705<7101@1`00FPL00`071`0I1`03
00L704l7101D1`00F`L00`071`0H1`0300L704/7101H1`00G0L00`071`0G1`0300L704L7101L1`00
G@L201L700<01`L0A0L30607001O1`0300L701@700<01`L0@0L406<7001P1`0300L701<700<01`L0
?0L406L7001Q1`0300L7014700<01`L0>@L406/7001R1`804@L00`071`0e1`@0K`L006@700<01`L0
3PL00`071`0a1`@0L`L006D700<01`L03@L00`071`0^1`<0M`L006H700<01`L030L00`071`0Z1`@0
NPL006L70P0<1`0300L702H7101n1`00J@L00`071`091`0300L7028710221`00JPL00`071`081`03
00L701h710261`00J`L00`071`071`0300L701X7102:1`00K0L00`071`061`0300L701H7102>1`00
K@L200H700<01`L04`L30987001_1`0300L700<700<01`L03`L409D7001`1`0300L7008700<01`L0
2`L409T7001a1`0500L71`002@L409d7001b1`8000<700L010L40:47001d1`8000<700000P2U1`00
M@L20:T70000\
\>"],
  ImageRangeCache->{{{0, 287}, {239.812, 0}} -> {-0.000394894, 0.054276, \
0.00331252, 0.00331252}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[10]= "]
}, Open  ]],

Cell[TextData[{
  "This tessellates the ",
  StyleBox["Polygon", "MR"],
  " primitive within a ",
  StyleBox["Graphics3D", "MR"],
  " object. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[TessellatePolygons3D[Graphics3D[Polygon[data3D]]]]\)], "Input",
  CellLabel->"In[11]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83627 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.05274 -0.0571427 1.05274 [
[ 0 0 0 0 ]
[ 1 .83627 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
.41616 .60683 m
.03908 .25019 L
s
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
.41616 .60683 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
0 0 m
1 0 L
1 .83627 L
0 .83627 L
closepath
clip
newpath
.5 Mabswid
.37777 .48994 m .52119 .58346 L .35729 .64084 L closepath p .547 .62 .876 r
F P
0 g
s
.52119 .58346 m .63484 .54367 L .74941 .73227 L closepath p .547 .62 .876 r
F P
0 g
s
.39212 .38416 m .37777 .48994 L .14175 .33605 L closepath p .547 .62 .876 r
F P
0 g
s
.84301 .47078 m .63484 .54367 L .55722 .41588 L closepath p .547 .62 .876 r
F P
0 g
s
.55722 .41588 m .39212 .38416 L .41874 .18792 L closepath p .547 .62 .876 r
F P
0 g
s
.25 Mabswid
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{288, 240.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000l0P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53JbLW9`00?g=cLda<C240<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7i/30`9T0I_ooc020
P800082006IVc3<cIP2009VIod:JYb8R8_mV<`00P00g??mVc9W<c9W<oiWo09Wo<iWoIYWoVIWoc9Wo
ol`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI
<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<coool0<ol0I_l0VOl0c?lc
0?lc<olcI_lcVOlcc?lcoomV0?mVI_mVVOmVoonI0?nI<l470P1M1`00_`L200031`0005`7002l1`<0
0`L205`7002i1`<01PL00`07001K1`00]`L200T700@01`L0FPL00;@70`0;1`0400L705X7002b1`80
3PL01@071`L005T7002_1`<040L00`071`021`0300L705H7002]1`804`L00`071`021`0300L705H7
002Z1`<05@L00`071`031`0300L705D7002W1`<06@L00`071`031`0300L705@7002U1`8070L00`07
1`031`0300L705@7002R1`<07PL00`071`041`0300L705<7002P1`808@L00`071`051`0300L70587
002M1`<08`L00`071`051`0300L70587002K1`809PL00`071`061`0300L70547002H1`<0:0L00`07
1`071`0300L70507002E1`<0:`L00`071`071`0300L70507002C1`80;PL00`071`081`0300L704l7
002@1`<0<0L00`071`091`0300L704h7002>1`80<`L00`071`091`0300L704h7002;1`<0=@L00`07
1`0:1`0300L704d700291`80>0L00`071`0:1`0300L704d700261`<0>PL00`071`0;1`0300L704`7
00231`<0?@L00`071`0<1`0300L704/700211`80@0L00`071`0<1`0300L704/7001n1`<0@PL00`07
1`0=1`0300L704X7001l1`80A@L00`071`0>1`0300L704T7001i1`<0A`L00`071`0>1`0300L704T7
001f1`<0B`L00`071`0>1`0300L704P7001d1`80CPL00`071`0?1`0300L704L7001a1`<0D0L00`07
1`0?1`0300L704L7001_1`80D`L00`071`0@1`0300L704H7001/1`<0E@L00`071`0A1`0300L704D7
001Z1`80F0L00`071`0A1`0300L704D7001W1`<0FPL00`071`0B1`0300L704@7001T1`<0G@L00`07
1`0C1`0300L704<7001R1`80H0L00`071`0C1`0300L704<7001O1`<0HPL00`071`0D1`0300L70487
001M1`80I@L00`071`0E1`0300L70447001J1`<0I`L00`071`0E1`0300L70447001H1`80JPL00`07
1`0F1`0300L70407001E1`<0K0L00`071`0G1`0300L703l7001B1`<0K`L00`071`0G1`0300L703l7
001@1`80LPL00`071`0H1`0300L703h7001=1`<0M0L00`071`0I1`0300L703d7001;1`80M`L00`07
1`0I1`0300L703d700181`<0N@L00`071`0J1`0300L703`700151`<0O@L00`071`0J1`0300L703/7
00131`80P0L00`071`0J1`0300L703/700101`<0PPL00`071`0K1`0300L703X7000n1`80Q@L00`07
1`0L1`0300L703T7000k1`<0Q`L00`071`0L1`0300L703T7000i1`80RPL00`071`0M1`0300L703P7
000f1`<0?`L00`071`1:1`0300L701h700<01`L0=`L003<70`121`80B`L00`071`0N1`0300L703L7
000a1`80A@L204/700<01`L07`L00`071`0f1`00;PL304L700<0LP00BPL00`071`0P1`0300L703D7
000/1`80B@L0101bN01:1`0300L7020700<01`L0=@L002T70`1;1`05095bT@00B@L00`071`0Q1`03
00L703@7000W1`80CPL01P1bN79h04P700<01`L08PL00`071`0c1`0090L3050700H0TG:ALP181`03
00L7028700<01`L0<`L002470`1C1`07079hLWQb00171`0300L702<700<01`L0<PL001l70P1F1`07
095bTG:A00171`0300L702<700<01`L0<PL001`70`1H1`08079hLWQbN0161`0300L702@700<01`L0
<@L001X70P1J1`0:07:ALY5bTG:A04D700<01`L09@L00`071`0`1`005`L305`700X0N79hLWQbN780
A@L00`071`0U1`0300L70307000E1`80G`L02`1bTG:ALY5bTG8004D700<01`L09@L00`071`0_1`00
4PL3064700/0N79hLWQbN79h00151`0300L702H700<01`L0;PL000l70`1T1`0<07:ALY5bTG:ALY40
A0L00`071`0V1`0300L702h7000=1`80I`L03@1hLWQbN79hLWQbN000@`L00`071`0W1`0300L702d7
000;1`80J@L03@1bTG:ALY5bTG:ALP00@`L00`071`0X1`0300L702`7000;1`80J0L03`1bN79hLWQb
N79hLWQb00121`0300L702P700<01`L0;0L000/700<01`00I`L03`2ALY5bTG:ALY5bTG:A00121`03
00L702T700<01`L0:`L000/700@01`L0IPL0401bN79hLWQbN79hLWQbN0111`0300L702X700<01`L0
:PL000X700<01`L00PL00`071`1S1`0A095bTG:ALY5bTG:ALY5bT@00@0L00`071`0Z1`0300L702X7
000:1`0300L700<700<01`L0HPL04@1bN79hLWQbN79hLWQbN78003l70P0]1`0300L702T7000:1`03
00L700@700<01`L0H@L04P2ALY5bTG:ALY5bTG:ALY5b03/70`021`0300L702/700<01`L0:0L000X7
00<01`L01@L00`071`1P1`0B079hLWQbN79hLWQbN79hLWP0>0L300D700<01`L0:`L00`071`0X1`00
2PL00`071`061`0300L705h701@0LY5bTG:ALY5bTG:ALY5bTG:A03@70`091`0300L702/700<01`L0
9`L000X700<01`L01`L00`071`1M1`0E07QbN79hLWQbN79hLWQbN79hLWP003070`0=1`0300L702/7
00<01`L09PL000T700<01`L02@L205d701D0LY5bTG:ALY5bTG:ALY5bTG:ALP00;@L3014700<01`L0
:PL00`071`0V1`002@L00`071`0;1`0300L705X701H0N79hLWQbN79hLWQbN79hLWQbN780:PL201@7
00<01`L0:`L00`071`0U1`002@L00`071`0<1`0300L705T701H0LY5bTG:ALY5bTG:ALY5bTG:ALY40
9`L301L700<01`L0:`L00`071`0T1`002@L00`071`0=1`0300L705P701L0N79hLWQbN79hLWQbN79h
LWQbN79h000S1`<06`L00`071`0Z1`0300L702@700091`0300L700h700<01`L0E`L0601bTG:ALY5b
TG:ALY5bTG:ALY5bTG:A01l70`0O1`0300L702X700<01`L08`L000T700<01`L03`L00`071`1E1`0I
079hLWQbN79hLWQbN79hLWQbN79hLWQb000L1`<08PL00`071`0[1`0300L7028700091`0300L70107
00<01`L0E0L06P2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8060L302H700<01`L0:PL00`071`0R1`00
20L00`071`0B1`0300L705<701X0LWQbN79hLWQbN79hLWQbN79hLWQbN79h01D70`0Z1`0300L702X7
00<01`L08@L000P700<01`L04`L00`071`1B1`0K095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400147
0`0^1`0300L702X700<01`L080L000P700<01`L050L00`071`1A1`0L079hLWQbN79hLWQbN79hLWQb
N79hLWQbN79h00d70`0a1`0300L702X700<01`L080L000P700<01`L05@L00`071`1@1`0L095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5b00X70`0e1`0300L702X700<01`L07`L000P700<01`L05PL00`07
1`1?1`0M079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP001PL303T700<01`L0:PL00`071`0N1`00
20L00`071`0G1`0300L704d701h0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@041`80?@L00`07
1`0Y1`0300L701h700081`0300L701P700<01`L0C0L07P1hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN0@0?`L00`071`0Z1`0300L701d700071`0300L701X700<01`L0B`L0701bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG84048700<01`L0:PL00`071`0L1`001`L00`071`0K1`0300L700<0A`L06@1h
LWQbN79hLWQbN79hLWQbN79hLWQbN7800`00179hLP131`0300L702T700<01`L070L000L700<01`L0
70L00`071`07048701H0LY5bTG:ALY5bTG:ALY5bTG:ALY5b0`0027:ALY5bTG80@`L00`071`0Y1`03
00L701/700071`0300L701d700T01`L7079hLWP01@0m1`0C07QbN79hLWQbN79hLWQbN79hLP03000;
LWQbN79hLWQbN000@`L00`071`0Z1`0300L701X700071`0300L701h700@01`L70P001i5bTG:ALY40
1@0h1`0@07:ALY5bTG:ALY5bTG:ALP<000mbTG:ALY5bTG:ALY5bT@00@`L00`071`0Y1`0300L701X7
00071`0300L701l700<01`L00PL0301hLWQbN79hLWQbN0H0<@L03P1bN79hLWQbN79hLWQb0`004g9h
LWQbN79hLWQbN79hLWQbN000@`L00`071`0Y1`0300L701T700061`0300L7024700<01`L00PL2000?
LY5bTG:ALY5bTG:ALY5b00D0;0L02`2ALY5bTG:ALY5b00<001IbTG:ALY5bTG:ALY5bTG:ALY5bTG80
@`L00`071`0Z1`0300L701P700061`0300L702870P041`80019hLWQbN79hLWQbN79hLWQbN78502L7
00P0LWQbN79hLP<001YbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04<700<01`L0:@L00`071`0H1`00
1PL00`071`0T1`0300L700<701L0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP05028700D0TG:ALP03000M
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@00A0L00`071`0Y1`0300L701L700061`0300L702D7
00<01`L00`L2000ILWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0501d700<0LWP00P008G9hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79h00141`0300L702T700<01`L05PL000H700<01`L09PL00`07
1`041`0N07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1@0H1`<002BALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@131`0300L702T700<01`L05PL000H700<01`L09`L00`071`041`80
021hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPD040L4000VLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP141`0300L702T700<01`L05@L000H700<01`L0:0L00`071`051`0U
095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0600L70`021`0Y07:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00A0L00`071`0X1`0300L701D700051`0300L702X7
00<01`L01@L2000XLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0L01@L0:@1h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP004D700<01`L0:0L00`071`0D1`00
1@L00`071`0[1`0300L700H702T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
T@030003T@0000<00PL0:P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A04@7
00<01`L0:@L00`071`0C1`001@L00`071`0/1`0300L700H70P008gQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79h00<000UhLWQbN79hLWP01@00:7QbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN0141`0300L702P700<01`L04`L000D700<01`L0;@L00`071`071`0P095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY43000?TG:ALY5bTG:ALY5bTG8000871@008i5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8004D700<01`L0:0L00`071`0B1`001@L00`071`0^1`03
00L700L70P006W9hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0`004WQbN79hLWQbN79hLWQbN79h00L7
1P007W9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04D700<01`L0:0L00`071`0A1`001@L00`07
1`0_1`0300L700P70P005I5bTG:ALY5bTG:ALY5bTG:ALY5bT@03000ETG:ALY5bTG:ALY5bTG:ALY5b
TG8000d71@006G:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@00A@L00`071`0X1`0300L7014700051`03
00L7030700<01`L02@L04P1hLWQbN79hLWQbN79hLWQbN0<001MhLWQbN79hLWQbN79hLWQbN79hLWQb
000C1`D001EbN79hLWQbN79hLWQbN79hLWQbN000A@L00`071`0X1`0300L7010700041`0300L70387
00<01`L02@L2000<LY5bTG:ALY5bTG:A0`006Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4060L5000A
LY5bTG:ALY5bTG:ALY5bT@00A@L00`071`0X1`0300L700l700041`0300L703<700<01`L02PL02P1b
N79hLWQbN782000MN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP007@L5000<LWQbN79hLWQbN780
APL00`071`0W1`0300L700l700041`0300L703@700<01`L02PL20004TG:ALP<001mbTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY4002871P001i5bTG:ALP00A@L00`071`0X1`0300L700h700041`03
00L703D700<01`L02`L4000RLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb02P71@000gP0
1`151`0300L702P700<01`L03@L000@700<01`L0=PL00`071`081`D002=bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:A000]1`D0A0L00`071`0W1`0300L700d700041`0300L703L700<01`L0
10L300D702<0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb000`1`0307P000@0@0L00`07
1`0W1`0300L700`700031`0300L703T700<01`L00`091`80022ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:A030700L0LY5bTG:A00D0>`L00`071`0X1`0300L700/700031`0300L703T70`0>1`0O
07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h000b1`0;079hLWQbN79hLWP01@0g1`0300L702L7
00<01`L02`L000<700<01`L0=PL300870P0>1`8001abTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
<PL0402ALY5bTG:ALY5bTG:ALY46038700<01`L09`L00`071`0:1`000`L00`071`0c1`<01`L00`07
1`0=1`8001YhLWQbN79hLWQbN79hLWQbN79hLWQbN79h03<701D0N79hLWQbN79hLWQbN79hLWQbN780
1@0]1`0300L702P700<01`L02@L000<700<01`L0<0L300/700<01`L03PL06P2ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG80=0L06@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG801@0Y1`0300L702L700<01`L0
2@L000<700<01`L0;@L300l700<01`L03PL2000GLWQbN79hLWQbN79hLWQbN79hLWQbN000=0L07P1b
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPD09@L00`071`0V1`802PL000<700<01`L0:`L201<7
00<01`L03`L05`1bTG:ALY5bTG:ALY5bTG:ALY5bTG8003D70280LY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5b1@0Q1`0300L702870`000`L01`091`000PL00`071`0Y1`<05PL00`071`0?1`80
01AhLWQbN79hLWQbN79hLWQbN79h03H702H0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLPD070L00`071`0N1`@010L00`071`081`000PL00`071`0V1`<06PL00`071`0@1`0C095bTG:A
LY5bTG:ALY5bTG:A000g1`0[095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LP0501P700<01`L06PL300P700<01`L020L0008700<01`L08`L301h700<01`L040L2000@LWQbN79h
LWQbN79hLWQb03P702l0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LP0501@700<01`L05PL300`700<01`L01`L0008700<01`L080L3028700<01`L04@L0401bTG:ALY5b
TG:ALY5bT@0h1`0d07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALPH03`L00`071`0A1`@03`L00`071`071`000PL00`071`0M1`<09PL00`071`0A1`8000ehLWQb
N79hLWQbN78003T703T0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWP01@0:1`0300L700h70`0C1`0300L700L700021`0300L701X70`0Z1`0300L70187
00d0TG:ALY5bTG:ALY4003X703d0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:A00D01PL00`071`0:1`<05PL00`071`071`000PL00`071`0G1`<0
;PL00`071`0B1`8000YbN79hLWQbN780>PL0@P1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0D00PL00`071`061`<06@L00`071`071`00
00<700L05PL3038700<01`L04`L20008TG:ALY5bT@0k1`16095bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@@00`L401`700<01`L0
1`L000031`0701<70`0f1`0300L701@700P0N79hLWQb03`704<0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<00PL4020700<01`L0
1`L000031`0701070`0j1`0300L701@70P0017:ALP0m1`1007:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<00`L4028700<01`L01`L00003
1`0700h70P0n1`0300L701D700@0LWP0?PL0?@1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00P021`@010L00`071`0P1`0300L700H700000`L0
1`0;1`<0@@L00`071`0E1`<0?PL0>P2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY4300041`0000T700<01`L07`L00`071`061`0000<700L020L304D7
00<01`L05PL00`071`0m1`0f07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h0`0010L0000<1`0300L701l700<01`L01PL0000300L700D70`191`0300L701D7
0`0n1`0b095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY470107
00<01`L07PL00`071`061`0000<01`L00PL304d700<01`L050L0101hLP0m1`0_079hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP01P0E1`0300L701d700<01`L01PL00003
00L00080D@L201@700@0LY5b0P0l1`0/07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG8501T700<01`L070L00`071`061`000P1F1`0300L7010700P0LWQbN79h03`702P0LWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb1@0L1`0300L701`700<01`L01PL00003
1`0705H700<01`L03`L0202ALY5bTG:A0P0j1`0U095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP05020700<01`L06`L00`071`061`000PL205H700<01`L03PL02`1bN79hLWQbN78003X7
0240N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780100U1`0300L701/700<01`L01@L000@7
00<01`L0E0L00`071`0=1`0;095bTG:ALY5bTG800P0h1`0N07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5b100Y1`0300L701X700<01`L01@L000D700<01`L0E0L00`071`0<1`0>079hLWQbN79hLWQb
N00h1`0K079hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<0;0L00`071`0J1`0300L700D700061`03
00L705@700<01`L02`L03P2ALY5bTG:ALY5bTG:A0P0g1`0G07:ALY5bTG:ALY5bTG:ALY5bTG:ALY40
0`0`1`0300L701T700<01`L01@L000L70P1E1`0300L700X70140LWQbN79hLWQbN79hLWQb000f1`0D
07QbN79hLWQbN79hLWQbN79hLWP303@700<01`L060L00`071`051`002@L00`071`1C1`0300L700P7
0180LY5bTG:ALY5bTG:ALY5bTG8203D70100TG:ALY5bTG:ALY5bTG:A0`0g1`0300L701P700<01`L0
1@L000X700<01`L0D`L00`071`071`0E07QbN79hLWQbN79hLWQbN79hLWP003D700`0N79hLWQbN79h
LWP303/700<01`L05`L00`071`051`002`L00`071`1C1`0300L700H701D0LY5bTG:ALY5bTG:ALY5b
TG:ALY400P0c1`0:07:ALY5bTG:ALP80?`L00`071`0G1`0300L700@7000<1`0300L705<700<01`L0
1@L05`1hLWQbN79hLWQbN79hLWQbN79hLWQb0080<PL01P1bN79hLP<0@PL00`071`0F1`0300L700@7
000=1`80E0L00`071`041`0J07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0`1`8000>ALP000P151`03
00L701H700<01`L010L000l700<01`L0DPL00`071`031`0J07QbN79hLWQbN79hLWQbN79hLWQbN79h
LWP202/70`0010L000191`0300L701D700<01`L010L0010700<01`L0DPL00`071`021`0M07:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP009`L300071`0007:A001:1`0300L701@700<01`L010L00147
00<01`L0DPL08@071`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0202870`002PL0001bN79h
LP1;1`0300L701<700<01`L010L001870P1C1`0S00L0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bT@007@L4000>1`0007:ALY5bTG:ALP1:1`0300L701<700<01`L010L001@700<01`L0D@L2000P
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP201P70`021`<000ebN79hLWQbN79hLWP004/7
00<01`L04PL00`071`041`005@L00`071`1A1`0T095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG8050L300870`004G:ALY5bTG:ALY5bTG:ALY4004/700<01`L04PL00`071`031`005PL00`07
1`1@1`0T079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb0P0>1`@00PL3000ELWQbN79h
LWQbN79hLWQbN79hLWP004/700<01`L04@L00`071`031`005`L2050702L0TG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@002PL300<70`0067:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b04/7
00<01`L04@L00`071`031`006@L00`071`1=1`0W079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79h00801@L300<70`00779hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1;1`0300L70107
00<01`L00`L001X700<01`L0C0L0:@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5b00D00`L3000OLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A001<1`0300L700l700<01`L0
0`L001/700<01`L0BPL0:`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780
0P021`<002=bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h001<1`0300L700h700<01`L0
0`L001`700<01`L0B@L0;01bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
0`009g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A001;1`0300L700h700<01`L0
0`L001d70P191`0Y07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800`021`80
02IbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04`700<01`L03@L00`071`031`00
7`L00`071`161`0V07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8300L702L0LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00C0L00`071`0=1`0300L70087000P1`03
00L704D702<0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0300/70P009GQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP00C0L00`071`0<1`0300L70087000Q1`0300L704@7
0200LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<040L09@2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bT@00C0L00`071`0<1`0300L70087000R1`80A0L07@1hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQb00<050L2000SLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN000
C0L00`071`0;1`0300L70087000T1`0300L7040701/0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
0`0I1`0S07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00C@L00`071`0:1`0300L70087
000U1`0300L703l701P0LWQbN79hLWQbN79hLWQbN79hLWQbN78301d70P008GQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQb001<1`0300L700X700<01`L00PL002H700<01`L0?PL05P2ALY5bTG:A
LY5bTG:ALY5bTG:ALY4202870P0087:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80C0L00`07
1`091`0300L70087000W1`80?PL04`1bN79hLWQbN79hLWQbN79hLWP00`0V1`0P079hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN01=1`0300L700T700<01`L00@L002T700<01`L0>`L0402ALY5bTG:A
LY5bTG:ALY4302X70P007Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A04d700<01`L020L00`07
1`011`00:PL00`071`0j1`0=079hLWQbN79hLWQbN00402h701h0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLP1=1`0300L700P700<01`L00@L002/700<01`L0>@L02P2ALY5bTG:ALY4300<700<01`L0
;@L2000LLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b04d700<01`L01`L00`071`011`00;0L00`07
1`0g1`0807QbN79hLWP300H700<01`L0;`L07@1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78004d7
00<01`L01PL00`071`011`00;@L203L700D0LY5bT@0300T700<01`L0<0L2000JTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bT@1>1`0300L700D700<01`L00@L002l700<01`L0=0L00`1h000200`700<01`L0
<PL06`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79h001=1`0300L700D700<01`L00@L0030700<01`L0
<`L200l700<01`L0<`L2000HLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80CPL00`071`041`0300L70047
000a1`0300L704<700<01`L0=@L06@1bN79hLWQbN79hLWQbN79hLWQbN79hLP00CPL00`071`041`40
0@L11`00<PL204<700<01`L0=PL2000GTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00CPL00`071`031`40
0@L11`00=0L00`071`101`0300L703P701L0N79hLWQbN79hLWQbN79hLWQbN79h001>1`0300L700<7
0@011`47000e1`0300L703l700<01`L0>@L2000ELY5bTG:ALY5bTG:ALY5bTG:ALY4004h700<01`L0
0PL100470@L003H700<01`L0?PL00`071`0k1`0F079hLWQbN79hLWQbN79hLWQbN79h04h700D01`L7
00021`00=`L203h700<01`L0?0L2000CTG:ALY5bTG:ALY5bTG:ALY5b001?1`0400L70087000i1`03
00L703/700<01`L0?PL2000BLWQbN79hLWQbN79hLWQbN780CPL010071`021`00>PL00`071`0i1`03
00L704470180LY5bTG:ALY5bTG:ALY5bT@1?1`0300L00087000k1`0300L703P700<01`L0@PL2000@
N79hLWQbN79hLWQbN79h04l700<01`000@L003`700<01`L0=`L00`071`141`0A095bTG:ALY5bTG:A
LY5bT@00C`L20047000m1`80=`L00`071`151`8000ibN79hLWQbN79hLWQb04l70P011`00?`L00`07
1`0d1`0300L704L700l0LY5bTG:ALY5bTG:ALP00CPL2004700101`0300L703<700<01`L0B0L2000<
N79hLWQbN79hLWP0BPL400<700111`0300L7038700<01`L0BPL03@2ALY5bTG:ALY5bT@00A@L400L7
00121`80<PL00`071`1;1`8000]bN79hLWQbN79h00101`@02`L004@700<01`L0;`L00`071`1=1`0;
07:ALY5bTG:ALP00?0L400l700151`0300L702h700<01`L0CPL20009N79hLWQbN78003L7100C1`00
APL00`071`0]1`0300L7050700T0TG:ALY5bT@00=0L301L700171`80;@L00`071`1A1`8000MbN79h
LWP002l7100J1`00B@L00`071`0Z1`0300L705<70P001Y5bTG:A02X7100N1`00BPL00`071`0Y1`03
00L705D700H0N79hLP0V1`@08PL004/700<01`L0:0L00`071`1F1`8000AbTG808@L402H7001<1`03
00L702L700<01`L0F0L01@1bN78001`7100Z1`00C@L202L700<01`L0F@L20003T@0701L7100^1`00
C`L00`071`0T1`0300L705/700<0N00050L30387001@1`0300L702<700<01`L0G0L20107100e1`00
D@L00`071`0R1`0300L705h700<01`L02@L403T7001B1`808PL00`071`1V1`@0?@L005@700<01`L0
7`L00`071`1R1`@0@@L005D700<01`L07PL00`071`1N1`@0A@L005H700<01`L07@L00`071`1K1`<0
B@L005L70P0M1`0300L705L7101<1`00F@L00`071`0J1`0300L705<7101@1`00FPL00`071`0I1`03
00L704l7101D1`00F`L00`071`0H1`0300L704/7101H1`00G0L00`071`0G1`0300L704L7101L1`00
G@L201L700<01`L0A0L30607001O1`0300L701@700<01`L0@0L406<7001P1`0300L701<700<01`L0
?0L406L7001Q1`0300L7014700<01`L0>@L406/7001R1`804@L00`071`0e1`@0K`L006@700<01`L0
3PL00`071`0a1`@0L`L006D700<01`L03@L00`071`0^1`<0M`L006H700<01`L030L00`071`0Z1`@0
NPL006L70P0<1`0300L702H7101n1`00J@L00`071`091`0300L7028710221`00JPL00`071`081`03
00L701h710261`00J`L00`071`071`0300L701X7102:1`00K0L00`071`061`0300L701H7102>1`00
K@L200H700<01`L04`L30987001_1`0300L700<700<01`L03`L409D7001`1`0300L7008700<01`L0
2`L409T7001a1`0500L71`002@L409d7001b1`8000<700L010L40:47001d1`8000<700000P2U1`00
M@L20:T70000\
\>"],
  ImageRangeCache->{{{0, 287}, {239.812, 0}} -> {-0.000394894, 0.054276, \
0.00331252, 0.00331252}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[11]= "]
}, Open  ]],

Cell["\<\
Polygons embedded in three dimensions are projected onto a plane \
before they are tessellated. The tessellation procedure generates new \
vertices in this plane only; thus, there might be unexpected results for non\
\[Dash]flat polygons.\
\>", "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
                {
                  StyleBox["GraphicalDebugging",
                    "MR"], 
                  StyleBox["False",
                    
                    "MR"], \(whether\ to\ display\ each\ step\ of\ the\ \
tessellation\ algorithm\)},
                {
                  StyleBox["WindingRule",
                    "MR"], 
                  StyleBox["OddQ",
                    "MR"], 
                  RowBox[{
                    StyleBox["a",
                      "MR"], " ", "function", " ", "which", " ", "is", " ", 
                    "applied", " ", "to", " ", "the", " ", "winding", " ", 
                    "number", " ", "of", " ", "each", " ", "polygon", " ", 
                    "of", " ", "the", " ", "tessellation", " ", "and", " ", 
                    "decides", " ", "whether", " ", "the", " ", "polygon", 
                    " ", "is", " ", "returned"}]}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{
  "PolygonTessellation:GraphicalDebugging", "PolygonTessellation:WindingRule"}
    ],

Cell["Option for all tessellation functions of this package.  ", "Caption"],

Cell["\<\
This displays each step of the tessellation algorithm decomposing a \
polygon into simple polygons (compare [1]).\
\>", "MathCaption"],

Cell[BoxData[
    \(PolygonTessellation[data2D, GraphicalDebugging -> True]\)], "Input"],

Cell["This returns all polygons of the tessellation. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      TessellatePolygons3D[Graphics3D[Polygon[data3D]], 
        WindingRule -> \((True &)\)]]\)], "Input",
  CellLabel->"In[12]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83627 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.05274 -0.0571427 1.05274 [
[ 0 0 0 0 ]
[ 1 .83627 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
.41616 .60683 m
.03908 .25019 L
s
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
.41616 .60683 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.40897 .83627 L
s
.40897 .83627 m
.41616 .60683 L
s
0 0 m
1 0 L
1 .83627 L
0 .83627 L
closepath
clip
newpath
.5 Mabswid
.37777 .48994 m .52119 .58346 L .35729 .64084 L closepath p .547 .62 .876 r
F P
0 g
s
.52119 .58346 m .63484 .54367 L .74941 .73227 L closepath p .547 .62 .876 r
F P
0 g
s
.52119 .58346 m .37777 .48994 L p .55722 .41588 L .547 .62 .876 r
F P
0 g
s
.55722 .41588 m .63484 .54367 L .52119 .58346 L p .547 .62 .876 r
F P
0 g
s
.39212 .38416 m .37777 .48994 L .14175 .33605 L closepath p .547 .62 .876 r
F P
0 g
s
.37777 .48994 m .39212 .38416 L .55722 .41588 L p .547 .62 .876 r
F P
0 g
s
.84301 .47078 m .63484 .54367 L .55722 .41588 L closepath p .547 .62 .876 r
F P
0 g
s
.55722 .41588 m .39212 .38416 L .41874 .18792 L closepath p .547 .62 .876 r
F P
0 g
s
.25 Mabswid
.67645 0 m
.96812 .44027 L
s
.96812 .44027 m
1 .68213 L
s
1 .68213 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.03908 .25019 m
0 .50373 L
s
0 .50373 m
.69011 .26481 L
s
.69011 .26481 m
.67645 0 L
s
.67645 0 m
.03908 .25019 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{288, 240.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000l0P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53JbLW9`00?g=cLda<C240<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7i/30`9T0I_ooc020
P800082006IVc3<cIP2009VIod:JYb8R8_mV<`00P00g??mVc9W<c9W<oiWo09Wo<iWoIYWoVIWoc9Wo
ol`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI
<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<coool0<ol0I_l0VOl0c?lc
0?lc<olcI_lcVOlcc?lcoomV0?mVI_mVVOmVoonI0?nI<l470P1M1`00_`L200031`0005`7002l1`<0
0`L205`7002i1`<01PL00`07001K1`00]`L200T700@01`L0FPL00;@70`0;1`0400L705X7002b1`80
3PL01@071`L005T7002_1`<040L00`071`021`0300L705H7002]1`804`L00`071`021`0300L705H7
002Z1`<05@L00`071`031`0300L705D7002W1`<06@L00`071`031`0300L705@7002U1`8070L00`07
1`031`0300L705@7002R1`<07PL00`071`041`0300L705<7002P1`808@L00`071`051`0300L70587
002M1`<08`L00`071`051`0300L70587002K1`809PL00`071`061`0300L70547002H1`<0:0L00`07
1`071`0300L70507002E1`<0:`L00`071`071`0300L70507002C1`80;PL00`071`081`0300L704l7
002@1`<0<0L00`071`091`0300L704h7002>1`80<`L00`071`091`0300L704h7002;1`<0=@L00`07
1`0:1`0300L704d700291`80>0L00`071`0:1`0300L704d700261`<0>PL00`071`0;1`0300L704`7
00231`<0?@L00`071`0<1`0300L704/700211`80@0L00`071`0<1`0300L704/7001n1`<0@PL00`07
1`0=1`0300L704X7001l1`80A@L00`071`0>1`0300L704T7001i1`<0A`L00`071`0>1`0300L704T7
001f1`<0B`L00`071`0>1`0300L704P7001d1`80CPL00`071`0?1`0300L704L7001a1`<0D0L00`07
1`0?1`0300L704L7001_1`80D`L00`071`0@1`0300L704H7001/1`<0E@L00`071`0A1`0300L704D7
001Z1`80F0L00`071`0A1`0300L704D7001W1`<0FPL00`071`0B1`0300L704@7001T1`<0G@L00`07
1`0C1`0300L704<7001R1`80H0L00`071`0C1`0300L704<7001O1`<0HPL00`071`0D1`0300L70487
001M1`80I@L00`071`0E1`0300L70447001J1`<0I`L00`071`0E1`0300L70447001H1`80JPL00`07
1`0F1`0300L70407001E1`<0K0L00`071`0G1`0300L703l7001B1`<0K`L00`071`0G1`0300L703l7
001@1`80LPL00`071`0H1`0300L703h7001=1`<0M0L00`071`0I1`0300L703d7001;1`80M`L00`07
1`0I1`0300L703d700181`<0N@L00`071`0J1`0300L703`700151`<0O@L00`071`0J1`0300L703/7
00131`80P0L00`071`0J1`0300L703/700101`<0PPL00`071`0K1`0300L703X7000n1`80Q@L00`07
1`0L1`0300L703T7000k1`<0Q`L00`071`0L1`0300L703T7000i1`80RPL00`071`0M1`0300L703P7
000f1`<0?`L00`071`1:1`0300L701h700<01`L0=`L003<70`121`80B`L00`071`0N1`0300L703L7
000a1`80A@L204/700<01`L07`L00`071`0f1`00;PL304L700<0LP00BPL00`071`0P1`0300L703D7
000/1`80B@L0101bN01:1`0300L7020700<01`L0=@L002T70`1;1`05095bT@00B@L00`071`0Q1`03
00L703@7000W1`80CPL01P1bN79h04P700<01`L08PL00`071`0c1`0090L3050700H0TG:ALP181`03
00L7028700<01`L0<`L002470`1C1`07079hLWQb00171`0300L702<700<01`L0<PL001l70P1F1`07
095bTG:A00171`0300L702<700<01`L0<PL001`70`1H1`08079hLWQbN0161`0300L702@700<01`L0
<@L001X70P1J1`0:07:ALY5bTG:A04D700<01`L09@L00`071`0`1`005`L305`700X0N79hLWQbN780
A@L00`071`0U1`0300L70307000E1`80G`L02`1bTG:ALY5bTG8004D700<01`L09@L00`071`0_1`00
4PL3064700/0N79hLWQbN79h00151`0300L702H700<01`L0;PL000l70`1T1`0<07:ALY5bTG:ALY40
A0L00`071`0V1`0300L702h7000=1`80I`L03@1hLWQbN79hLWQbN000@`L00`071`0W1`0300L702d7
000;1`80J@L03@1bTG:ALY5bTG:ALP00@`L00`071`0X1`0300L702`7000;1`80J0L03`1bN79hLWQb
N79hLWQb00121`0300L702P700<01`L0;0L000/700<01`00I`L03`2ALY5bTG:ALY5bTG:A00121`03
00L702T700<01`L0:`L000/700@01`L0IPL0401bN79hLWQbN79hLWQbN0111`0300L702X700<01`L0
:PL000X700<01`L00PL00`071`1S1`0A095bTG:ALY5bTG:ALY5bT@00@0L00`071`0Z1`0300L702X7
000:1`0300L700<700<01`L0HPL04@1bN79hLWQbN79hLWQbN78003l70P0]1`0300L702T7000:1`03
00L700@700<01`L0H@L04P2ALY5bTG:ALY5bTG:ALY5b03/70`021`0300L702/700<01`L0:0L000X7
00<01`L01@L00`071`1P1`0B079hLWQbN79hLWQbN79hLWP0>0L300D700<01`L0:`L00`071`0X1`00
2PL00`071`061`0300L705h701@0LY5bTG:ALY5bTG:ALY5bTG:A03@70`091`0300L702/700<01`L0
9`L000X700<01`L01`L00`071`1M1`0E07QbN79hLWQbN79hLWQbN79hLWP003070`0=1`0300L702/7
00<01`L09PL000T700<01`L02@L205d701D0LY5bTG:ALY5bTG:ALY5bTG:ALP00;@L3014700<01`L0
:PL00`071`0V1`002@L00`071`0;1`0300L705X701H0N79hLWQbN79hLWQbN79hLWQbN780:PL201@7
00<01`L0:`L00`071`0U1`002@L00`071`0<1`0300L705T701H0LY5bTG:ALY5bTG:ALY5bTG:ALY40
9`L301L700<01`L0:`L00`071`0T1`002@L00`071`0=1`0300L705P701L0N79hLWQbN79hLWQbN79h
LWQbN79h000S1`<06`L00`071`0Z1`0300L702@700091`0300L700h700<01`L0E`L0601bTG:ALY5b
TG:ALY5bTG:ALY5bTG:A01l70`0O1`0300L702X700<01`L08`L000T700<01`L03`L00`071`1E1`0I
079hLWQbN79hLWQbN79hLWQbN79hLWQb000L1`<08PL00`071`0[1`0300L7028700091`0300L70107
00<01`L0E0L06P2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8060L302H700<01`L0:PL00`071`0R1`00
20L00`071`0B1`0300L705<701X0LWQbN79hLWQbN79hLWQbN79hLWQbN79h01D70`0Z1`0300L702X7
00<01`L08@L000P700<01`L04`L00`071`1B1`0K095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400147
0`0^1`0300L702X700<01`L080L000P700<01`L050L00`071`1A1`0L079hLWQbN79hLWQbN79hLWQb
N79hLWQbN79h00d70`0a1`0300L702X700<01`L080L000P700<01`L05@L00`071`1@1`0L095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5b00X70`0e1`0300L702X700<01`L07`L000P700<01`L05PL00`07
1`1?1`0M079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP001PL303T700<01`L0:PL00`071`0N1`00
20L00`071`0G1`0300L704d701h0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@041`80?@L00`07
1`0Y1`0300L701h700081`0300L701P700<01`L0C0L07P1hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN0@0?`L00`071`0Z1`0300L701d700071`0300L701X700<01`L0B`L0701bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG84048700<01`L0:PL00`071`0L1`001`L00`071`0K1`0300L700<0A`L06@1h
LWQbN79hLWQbN79hLWQbN79hLWQbN7800`00179hLP131`0300L702T700<01`L070L000L700<01`L0
70L00`071`07048701H0LY5bTG:ALY5bTG:ALY5bTG:ALY5b0`0027:ALY5bTG80@`L00`071`0Y1`03
00L701/700071`0300L701d700T01`L7079hLWP01@0m1`0C07QbN79hLWQbN79hLWQbN79hLP03000;
LWQbN79hLWQbN000@`L00`071`0Z1`0300L701X700071`0300L701h700@01`L70P001i5bTG:ALY40
1@0h1`0@07:ALY5bTG:ALY5bTG:ALP<000mbTG:ALY5bTG:ALY5bT@00@`L00`071`0Y1`0300L701X7
00071`0300L701l700<01`L00PL0301hLWQbN79hLWQbN0H0<@L03P1bN79hLWQbN79hLWQb0`004g9h
LWQbN79hLWQbN79hLWQbN000@`L00`071`0Y1`0300L701T700061`0300L7024700<01`L00PL2000?
LY5bTG:ALY5bTG:ALY5b00D0;0L02`2ALY5bTG:ALY5b00<001IbTG:ALY5bTG:ALY5bTG:ALY5bTG80
@`L00`071`0Z1`0300L701P700061`0300L702870P041`80019hLWQbN79hLWQbN79hLWQbN78502L7
00P0LWQbN79hLP<001YbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04<700<01`L0:@L00`071`0H1`00
1PL00`071`0T1`0300L700<701L0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP05028700D0TG:ALP03000M
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@00A0L00`071`0Y1`0300L701L700061`0300L702D7
00<01`L00`L2000ILWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0501d700<0LWP00P008G9hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79h00141`0300L702T700<01`L05PL000H700<01`L09PL00`07
1`041`0N07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1@0H1`<002BALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@131`0300L702T700<01`L05PL000H700<01`L09`L00`071`041`80
021hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLPD040L4000VLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP141`0300L702T700<01`L05@L000H700<01`L0:0L00`071`051`0U
095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0600L70`021`0Y07:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00A0L00`071`0X1`0300L701D700051`0300L702X7
00<01`L01@L2000XLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0L01@L0:@1h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP004D700<01`L0:0L00`071`0D1`00
1@L00`071`0[1`0300L700H702T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
T@030003T@0000<00PL0:P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A04@7
00<01`L0:@L00`071`0C1`001@L00`071`0/1`0300L700H70P008gQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79h00<000UhLWQbN79hLWP01@00:7QbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN0141`0300L702P700<01`L04`L000D700<01`L0;@L00`071`071`0P095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY43000ATG:ALY5bTG:ALY5bTG80LY401@008i5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8004D700<01`L0:0L00`071`0B1`001@L00`071`0^1`03
00L700L70P006W9hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0`006GQbN79hLWQbN79hLWQbN79h07Qb
N79hLWP01P007W9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04D700<01`L0:0L00`071`0A1`00
1@L00`071`0_1`0300L700P70P005I5bTG:ALY5bTG:ALY5bTG:ALY5bT@03000RTG:ALY5bTG:ALY5b
TG:ALY5bTG80LY5bTG:ALY5bTG:ALPD001UbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4004D700<01`L0
:0L00`071`0A1`001@L00`071`0`1`0300L700T70180N79hLWQbN79hLWQbN79hLWP3000ZN79hLWQb
N79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQb1@005G9hLWQbN79hLWQbN79hLWQbN79h
00151`0300L702P700<01`L040L000@700<01`L0<PL00`071`091`8000abTG:ALY5bTG:ALY43000b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG85000ALY5bTG:A
LY5bTG:ALY5bT@00A@L00`071`0X1`0300L700l700041`0300L703<700<01`L02PL02P1bN79hLWQb
N782000jN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLPD000abN79hLWQbN79hLP161`0300L702L700<01`L03`L000@700<01`L0=0L00`071`0:1`80
00BALY5b0`00@G:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5b00H000NALY5bTG8004D700<01`L0:0L00`071`0>1`0010L00`071`0e1`03
00L700/71000BW9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79h1@000gP01`151`0300L702P700<01`L03@L000@700<01`L0
=PL00`071`081`D0051bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@D0A0L00`071`0W1`0300L700d700041`03
00L703L700<01`L010L300D705D0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN01h00D0@0L00`071`0W1`03
00L700`700031`0300L703T700<01`L00`091`8005NALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY40
1@0k1`0300L702P700<01`L02`L000<700<01`L0>@L300h705`0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780
LWQbN79hLWQbN0D0=`L00`071`0W1`0300L700/700031`0300L703H70`021`803PL2001NLY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bT@H0<PL00`071`0W1`0300L700X700031`0300L703<7
0`071`0300L700d70P00HWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQb1@0]1`03
00L702P700<01`L02@L000<700<01`L0<0L300/700<01`L03PL0I`2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG801@0Y1`0300L702L700<01`L02@L000<700<01`L0;@L300l7
00<01`L03PL2001YLWQbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00D0
9@L00`071`0V1`802PL000<700<01`L0:`L201<700<01`L03`L0KP1bTG:ALY5bTG:ALY5bTG:ALY5b
TG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1@0Q1`0300L702870`000`L01`091`000PL00`07
1`0Y1`<05PL00`071`0?1`80071hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQb1@0L1`0300L701h710041`0300L700P700021`0300L702H70`0J1`0300L70107
07D0TG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
1@0H1`0300L701X70`081`0300L700P700021`0300L702<70`0N1`0300L701070P00Mg9hLWQbN79h
LWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00D050L00`07
1`0F1`<030L00`071`071`000PL00`071`0P1`<08PL00`071`0A1`1l07:ALY5bTG:ALY5bTG:A095b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALPH03`L00`071`0A1`@0
3`L00`071`071`000PL00`071`0M1`<09PL00`071`0A1`8007mhLWQbN79hLWQbN780LWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00D02PL00`071`0>1`<0
4`L00`071`071`000PL00`071`0J1`<0:PL00`071`0B1`24095bTG:ALY5bTG:A095bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A1@061`0300L700X7
0`0F1`0300L700L700021`0300L701L70`0^1`0300L701870P00QW9hLWQbN79hLP1bN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h1@021`03
00L700H70`0I1`0300L700L700000`L01`0F1`<0<PL00`071`0C1`8008VALY5bTG:A095bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
T@0400<7100L1`0300L700L700000`L01`0C1`<0=PL00`071`0D1`2707QbN79hLP1bN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<0
0PL4020700<01`L01`L000031`0701070`0j1`0300L701@70P00PG:ALP1bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0300<7100R1`03
00L700L700000`L01`0>1`80?PL00`071`0E1`1o079h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN002008710041`0300L7020700<01`L0
1PL000031`0700/70`111`0300L701D70`00N7:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@<000@700002@L00`071`0O1`0300L700H700000`L0
1`081`<0A@L00`071`0F1`1f07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN0<000@7000030L00`071`0O1`0300L700H700000`071`051`<0B@L00`07
1`0E1`<0071bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
1`0@1`0300L701h700<01`L01PL0000300L700870`1=1`0300L701@70700N780LWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h1P0E1`0300L701d700<01`L01PL00003
00L00080D@L201@700@0LY5b0P00J95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5b1@0I1`0300L701`700<01`L01PL00080EPL00`071`0@1`1/079hLWQbN01hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb1@0L1`0300L701`700<01`L01PL000031`0705H7
00<01`L03`L0202ALY5bTG:A0P00Gg:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00D0
80L00`071`0K1`0300L700H700021`80EPL00`071`0>1`1V079hLWQbN79hLP1bN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQb100U1`0300L701/700<01`L01@L000@700<01`L0E0L00`071`0=1`0;
095bTG:ALY5bTG800P00EY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b100Y1`0300L701X700<01`L0
1@L000D700<01`L0E0L00`071`0<1`1Q079hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N00302`700<01`L06PL00`071`051`001PL00`071`1D1`0300L700/700h0TG:ALY5bTG:ALY5bT@80
04ibTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:A
LY5bTG:ALY5bTG:ALY5bTG:ALY43030700<01`L06@L00`071`051`001`L205D700<01`L02PL0F`1b
N79hLWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWP00`0d1`0300L701P700<01`L01@L000T700<01`L0
D`L00`071`081`0B07:ALY5bTG:ALY5bTG:ALY5b0P00AI5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bT@0303L700<01`L060L00`07
1`051`002PL00`071`1C1`0300L700L705H0N79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN0<0>`L00`07
1`0G1`0300L700D7000;1`0300L705<700<01`L01PL05@1bTG:ALY5bTG:ALY5bTG:ALY5bT@02000m
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:A
LP0203l700<01`L05`L00`071`041`0030L00`071`1C1`0300L700D701L0N79hLWQbN79hLWQbN79h
LWQbN79hLP02000hN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N780LWQbN783048700<01`L05PL00`071`041`003@L205@700<01`L010L0CP1bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
T@2ALP<0A@L00`071`0F1`0300L700@7000?1`0300L7058700<01`L00`L06P1hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h0P00;g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQb00<0B@L00`071`0E1`0300L700@7000@1`0300L7058700<01`L00PL0B01bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<0
00=bT@00BPL00`071`0D1`0300L700@7000A1`0300L7058702401`L0LWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN7800P009WQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb0`001W9h
LWQb04/700<01`L04`L00`071`041`004PL205<704D01`2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800`002W:ALY5bTG:ALP1:1`03
00L701<700<01`L010L001@700<01`L0D@L2000PLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWP2000MLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800`003G9hLWQbN79hLWQbN000B`L00`07
1`0B1`0300L700@7000E1`0300L7054703d0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00<0015bTG:ALY5bTG:ALY5bTG:A001;1`0300L70187
00<01`L00`L001H700<01`L0D0L0901bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP80
01AhLWQbN79hLWQbN79hLWQbN79hLP<001EbN79hLWQbN79hLWQbN79hLWQbN000B`L00`071`0A1`03
00L700<7000G1`80D0L0=`2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:A
LY5bTG:ALY5bTG800`0067:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b04/700<01`L04@L00`071`031`00
6@L00`071`1=1`0W079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h008000]bN79h
LWQbN79hLP03000LLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb04/700<01`L040L00`071`031`00
6PL00`071`1<1`0a095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:A
LP03000OLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A001<1`0300L700l700<01`L00`L001/7
00<01`L0BPL0:`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800P000gQb
0002000SLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN000C0L00`071`0>1`0300L700<7
000L1`0300L704T702`0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<0
02MbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@00B`L00`071`0>1`0300L700<7
000M1`80B@L0:@1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<00PL2000V
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1<1`0300L700d700<01`L00`L001l7
00<01`L0APL09P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`071`0W07:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8004`700<01`L03@L00`071`021`0080L00`07
1`151`0S07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800`0;1`8002EhLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN78004`700<01`L030L00`071`021`008@L00`071`141`0P
07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG83010702D0TG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY4004`700<01`L030L00`071`021`008PL204@701d0N79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLP0301@70P008g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP004`7
00<01`L02`L00`071`021`0090L00`071`101`0K095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00<0
6@L08`1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8004d700<01`L02PL00`071`021`00
9@L00`071`0o1`0H079hLWQbN79hLWQbN79hLWQbN79hLWQb0`0M1`80025hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLP00C0L00`071`0:1`0300L70087000V1`0300L703h701H0TG:ALY5bTG:A
LY5bTG:ALY5bTG:A0P0R1`80021bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b04`700<01`L0
2@L00`071`021`009`L203h701<0LWQbN79hLWQbN79hLWQbN79h00<09PL0801bN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWP0C@L00`071`091`0300L70047000Y1`0300L703/70100TG:ALY5bTG:A
LY5bTG:A0`0Z1`8001jALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@1=1`0300L700P700<01`L0
0@L002X700<01`L0>PL03@1bN79hLWQbN79hLWP0100^1`0N07QbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN780C@L00`071`081`0300L70047000[1`0300L703T700X0TG:ALY5bTG:A0`031`0300L702d7
0P0077:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1=1`0300L700L700<01`L00@L002`700<01`L0
=`L0201hLWQbN79h0`061`0300L702l701d0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb001=1`03
00L700H700<01`L00@L002d70P0g1`0507:ALY400`091`0300L703070P006Y5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY40CPL00`071`051`0300L70047000_1`0300L703@700<0N0000P0<1`0300L70387
01/0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN000C@L00`071`051`0300L70047000`1`0300L703<7
0P0?1`0300L703<70P0067:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b04h700<01`L010L00`071`011`00
<@L00`071`131`0300L703D701T0LWQbN79hLWQbN79hLWQbN79hLWQbN78004h700<01`L010L10047
0@L003870P131`0300L703H70P005i5bTG:ALY5bTG:ALY5bTG:ALY5bTG8004h700<01`L00`L10047
0@L003@700<01`L0@0L00`071`0h1`0G07QbN79hLWQbN79hLWQbN79hLWQbN000CPL00`071`031`40
0@L11`00=@L00`071`0o1`0300L703T70P005G:ALY5bTG:ALY5bTG:ALY5bTG:A001>1`0300L70087
0@011`47000f1`0300L703h700<01`L0>`L05P1bN79hLWQbN79hLWQbN79hLWQbN01>1`0500L71`00
0PL003L70P0n1`0300L703`70P004i5bTG:ALY5bTG:ALY5bTG:ALP00C`L010071`021`00>@L00`07
1`0k1`0300L703h70P004W9hLWQbN79hLWQbN79hLWQb04h700@01`L00PL003X700<01`L0>@L00`07
1`111`0B07:ALY5bTG:ALY5bTG:ALY40C`L00`0700021`00>`L00`071`0h1`0300L704870P0047Qb
N79hLWQbN79hLWQbN01?1`0300L00047000l1`0300L703L700<01`L0A0L04@2ALY5bTG:ALY5bTG:A
LY4004l70P011`00?@L203L700<01`L0A@L2000>LWQbN79hLWQbN79hLP1?1`800@L003l700<01`L0
=0L00`071`171`0?07:ALY5bTG:ALY5bTG8004h70P011`00@0L00`071`0c1`0300L704P70P0037Qb
N79hLWQbN79h04X710031`00@@L00`071`0b1`0300L704X700d0TG:ALY5bTG:ALY4004D710071`00
@PL2038700<01`L0B`L2000;LWQbN79hLWQbN000@0L400/700141`0300L702l700<01`L0C@L02`1b
TG:ALY5bTG8003`7100?1`00A@L00`071`0^1`0300L704h70P002GQbN79hLWQb000g1`@04`L004H7
00<01`L0;@L00`071`1@1`09095bTG:ALY4003@70`0G1`00A`L202d700<01`L0D@L20007LWQbN79h
000_1`@06PL004T700<01`L0:PL00`071`1C1`8000JALY5bT@0Z1`@07PL004X700<01`L0:@L00`07
1`1E1`0607QbN7809PL40287001;1`0300L702P700<01`L0EPL20004LY5b0247100V1`00C0L00`07
1`0W1`0300L705P700D0LWQb000L1`@0:PL004d70P0W1`0300L705T70P000i401`0G1`@0;PL004l7
00<01`L090L00`071`1K1`0307P001@70`0b1`00D0L00`071`0S1`0300L705`70P0@1`@0=@L00547
00<01`L08PL00`071`1N1`0300L700T7100i1`00DPL2028700<01`L0IPL403d7001D1`0300L701l7
00<01`L0HPL40447001E1`0300L701h700<01`L0GPL404D7001F1`0300L701d700<01`L0F`L304T7
001G1`807@L00`071`1G1`@0C0L005T700<01`L06PL00`071`1C1`@0D0L005X700<01`L06@L00`07
1`1?1`@0E0L005/700<01`L060L00`071`1;1`@0F0L005`700<01`L05`L00`071`171`@0G0L005d7
0P0G1`0300L704@70`1P1`00G`L00`071`0D1`0300L70407101S1`00H0L00`071`0C1`0300L703`7
101W1`00H@L00`071`0A1`0300L703T7101[1`00HPL2014700<01`L0=@L406l7001T1`0300L700h7
00<01`L0<@L407<7001U1`0300L700d700<01`L0;PL307L7001V1`0300L700`700<01`L0:PL407X7
001W1`8030L00`071`0V1`@0OPL006T700<01`L02@L00`071`0R1`@0PPL006X700<01`L020L00`07
1`0N1`@0QPL006/700<01`L01`L00`071`0J1`@0RPL006`700<01`L01PL00`071`0F1`@0SPL006d7
0P061`0300L701<70`2B1`00K`L00`071`031`0300L700l7102E1`00L0L00`071`021`0300L700/7
102I1`00L@L01@071`L000T7102M1`00LPL200031`0700@7102Q1`00M0L200031`000080Y@L007D7
0P2Y1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {239.812, 0}} -> {-0.000394894, 0.054276, \
0.00331252, 0.00331252}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[12]= "]
}, Open  ]],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
                {
                  StyleBox["PlaneNormal",
                    "MR"], 
                  StyleBox["Automatic",
                    
                    "MR"], \(the\ normal\ vector\ used\ to\ project\ the\ \
three\[Dash]dimensional\ \ points\ onto\ a\ plane\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TradiationalForm]], "Text",
  CellTags->"PolygonTessellation:PlaneNormal"],

Cell[TextData[{
  "Additional option for ",
  StyleBox["PolygonTessellation3D", "MR"],
  ". "
}], "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
                {
                  StyleBox["FlatPolygons",
                    "MR"], 
                  StyleBox["All",
                    "MR"], \(the\ polygons\ to\ be\ tessellated\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->"PolygonTessellation:FlatPolygons"],

Cell[TextData[{
  "Additional option for ",
  StyleBox["TessellatePolygons3D", "MR"],
  ". "
}], "Caption"],

Cell[TextData[{
  "A specification of ",
  StyleBox["FlatPolygons->Automatic", "MR"],
  " will only tessellate those ",
  StyleBox["Polygon", "MR"],
  " primitives which have a third argument defining their \.13normal vector, \
which may be set to ",
  StyleBox["Automatic", "MR"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Note:", "TB"],
  " For further information about the ",
  StyleBox["PolygonTessellation", "MR"],
  " package and the latest release of this package you may contact the author \
electronically at Martin_Kraus_Germany@yahoo.com."
}], "Text"],

Cell["References", "Subsubsection",
  CellTags->{"S5.3.1", "1.28"}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[InvisibleSpace]\)\([1]\)\)\)], 
    "InlineFormula"],
  "  ",
  StyleBox["OpenGL Programming Guide, 2nd ed.", "IT"],
  ", Woo, Neider, Davis, Addison-Wesley, 1998."
}], "Text"]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{746, 850},
WindowMargins->{{46, Automatic}, {36, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "PolygonTessellation:PolygonTessellation"->{
    Cell[2448, 64, 5311, 131, 137, "Text",
      CellTags->{
      "PolygonTessellation:PolygonTessellation", 
        "PolygonTessellation:PolygonTessellation3D", 
        "PolygonTessellation:TessellatePolygons", 
        "PolygonTessellation:TessellatePolygons3D"}]},
  "PolygonTessellation:PolygonTessellation3D"->{
    Cell[2448, 64, 5311, 131, 137, "Text",
      CellTags->{
      "PolygonTessellation:PolygonTessellation", 
        "PolygonTessellation:PolygonTessellation3D", 
        "PolygonTessellation:TessellatePolygons", 
        "PolygonTessellation:TessellatePolygons3D"}]},
  "PolygonTessellation:TessellatePolygons"->{
    Cell[2448, 64, 5311, 131, 137, "Text",
      CellTags->{
      "PolygonTessellation:PolygonTessellation", 
        "PolygonTessellation:PolygonTessellation3D", 
        "PolygonTessellation:TessellatePolygons", 
        "PolygonTessellation:TessellatePolygons3D"}]},
  "PolygonTessellation:TessellatePolygons3D"->{
    Cell[2448, 64, 5311, 131, 137, "Text",
      CellTags->{
      "PolygonTessellation:PolygonTessellation", 
        "PolygonTessellation:PolygonTessellation3D", 
        "PolygonTessellation:TessellatePolygons", 
        "PolygonTessellation:TessellatePolygons3D"}]},
  "PolygonTessellation:GraphicalDebugging"->{
    Cell[107355, 2076, 1452, 34, 155, "Text",
      CellTags->{
      "PolygonTessellation:GraphicalDebugging", 
        "PolygonTessellation:WindingRule"}]},
  "PolygonTessellation:WindingRule"->{
    Cell[107355, 2076, 1452, 34, 155, "Text",
      CellTags->{
      "PolygonTessellation:GraphicalDebugging", 
        "PolygonTessellation:WindingRule"}]},
  "PolygonTessellation:PlaneNormal"->{
    Cell[135109, 2582, 781, 19, 79, "Text",
      CellTags->"PolygonTessellation:PlaneNormal"]},
  "PolygonTessellation:FlatPolygons"->{
    Cell[136004, 2609, 693, 17, 61, "Text",
      CellTags->"PolygonTessellation:FlatPolygons"]},
  "S5.3.1"->{
    Cell[137383, 2653, 67, 1, 34, "Subsubsection",
      CellTags->{"S5.3.1", "1.28"}]},
  "1.28"->{
    Cell[137383, 2653, 67, 1, 34, "Subsubsection",
      CellTags->{"S5.3.1", "1.28"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"PolygonTessellation:PolygonTessellation", 138354, 2682},
  {"PolygonTessellation:PolygonTessellation3D", 138674, 2689},
  {"PolygonTessellation:TessellatePolygons", 138991, 2696},
  {"PolygonTessellation:TessellatePolygons3D", 139310, 2703},
  {"PolygonTessellation:GraphicalDebugging", 139627, 2710},
  {"PolygonTessellation:WindingRule", 139825, 2715},
  {"PolygonTessellation:PlaneNormal", 140023, 2720},
  {"PolygonTessellation:FlatPolygons", 140160, 2723},
  {"S5.3.1", 140272, 2726},
  {"1.28", 140373, 2729}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 63, 0, 40, "Subsection"],
Cell[1783, 51, 662, 11, 88, "Text"],
Cell[2448, 64, 5311, 131, 137, "Text",
  CellTags->{
  "PolygonTessellation:PolygonTessellation", 
    "PolygonTessellation:PolygonTessellation3D", 
    "PolygonTessellation:TessellatePolygons", 
    "PolygonTessellation:TessellatePolygons3D"}],
Cell[7762, 197, 51, 0, 16, "Caption"],
Cell[7816, 199, 273, 7, 40, "Text"],
Cell[8092, 208, 46, 0, 30, "MathCaption"],
Cell[8141, 210, 102, 2, 26, "Input"],
Cell[8246, 214, 61, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[8332, 218, 153, 4, 26, "Input"],
Cell[8488, 224, 359, 6, 90, "Output"]
}, Open  ]],
Cell[8862, 233, 88, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[8975, 240, 86, 2, 26, "Input"],
Cell[9064, 244, 7904, 140, 184, 723, 46, "GraphicsData", "PostScript", \
"Graphics"],
Cell[16971, 386, 155, 4, 21, "Output"]
}, Open  ]],
Cell[17141, 393, 72, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[17238, 397, 95, 2, 26, "Input"],
Cell[17336, 401, 896, 16, 89, "Output"]
}, Open  ]],
Cell[18247, 420, 157, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[18429, 427, 95, 2, 26, "Input"],
Cell[18527, 431, 4643, 109, 184, 848, 57, "GraphicsData", "PostScript", \
"Graphics"],
Cell[23173, 542, 155, 4, 21, "Output"]
}, Open  ]],
Cell[23343, 549, 158, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[23526, 559, 109, 2, 26, "Input"],
Cell[23638, 563, 4643, 109, 184, 848, 57, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28284, 674, 155, 4, 21, "Output"]
}, Open  ]],
Cell[28454, 681, 217, 7, 40, "Text"],
Cell[28674, 690, 209, 8, 30, "MathCaption"],
Cell[28886, 700, 160, 4, 26, "Input"],
Cell[29049, 706, 77, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[29151, 710, 91, 2, 26, "Input"],
Cell[29245, 714, 30787, 490, 247, 1599, 125, "GraphicsData", "PostScript", \
"Graphics"],
Cell[60035, 1206, 157, 4, 21, "Output"]
}, Open  ]],
Cell[60207, 1213, 50, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[60282, 1217, 99, 2, 26, "Input"],
Cell[60384, 1221, 1333, 23, 123, "Output"]
}, Open  ]],
Cell[61732, 1247, 78, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[61835, 1251, 100, 2, 26, "Input"],
Cell[61938, 1255, 22248, 391, 247, 1790, 133, "GraphicsData", "PostScript", \
"Graphics"],
Cell[84189, 1648, 158, 4, 21, "Output"]
}, Open  ]],
Cell[84362, 1655, 162, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[84549, 1665, 114, 2, 26, "Input"],
Cell[84666, 1669, 22248, 391, 247, 1790, 133, "GraphicsData", "PostScript", \
"Graphics"],
Cell[106917, 2062, 158, 4, 21, "Output"]
}, Open  ]],
Cell[107090, 2069, 262, 5, 40, "Text"],
Cell[107355, 2076, 1452, 34, 155, "Text",
  CellTags->{
  "PolygonTessellation:GraphicalDebugging", 
    "PolygonTessellation:WindingRule"}],
Cell[108810, 2112, 75, 0, 16, "Caption"],
Cell[108888, 2114, 144, 3, 30, "MathCaption"],
Cell[109035, 2119, 88, 1, 26, "Input"],
Cell[109126, 2122, 70, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[109221, 2126, 159, 4, 26, "Input"],
Cell[109383, 2132, 25550, 441, 247, 2018, 145, "GraphicsData", "PostScript", \
"Graphics"],
Cell[134936, 2575, 158, 4, 21, "Output"]
}, Open  ]],
Cell[135109, 2582, 781, 19, 79, "Text",
  CellTags->"PolygonTessellation:PlaneNormal"],
Cell[135893, 2603, 108, 4, 16, "Caption"],
Cell[136004, 2609, 693, 17, 61, "Text",
  CellTags->"PolygonTessellation:FlatPolygons"],
Cell[136700, 2628, 107, 4, 16, "Caption"],
Cell[136810, 2634, 300, 9, 40, "Text"],
Cell[137113, 2645, 267, 6, 40, "Text"],
Cell[137383, 2653, 67, 1, 34, "Subsubsection",
  CellTags->{"S5.3.1", "1.28"}],
Cell[137453, 2656, 239, 7, 24, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

